
import csv
import codecs
import numpy as np
from sklearn.model_selection import cross_val_score
from matplotlib import pyplot as plt
from sklearn import svm
import liwcanalysis
np.random.seed(0)

def combineAllTweetsPerUser(dataset):
    users = {}
    for row in dataset:
        if row[-1] == 'class': continue
        TWETINDEX = 5 if len(row) == 7 else 7
        username = row[1]
        if username in users:
            users[username][5] += row[TWETINDEX]
        else:
            if len(row) == 7:
                users[username] = row[0:5] + [row[5], row[6]]
            else:
                users[username] = [row[1], row[5], row[2], row[3], row[6], row[7], row[9]]
    return list(users.values())


def loadDataset(filename):
    dataset = []
    csv_reader = csv.reader(codecs.open('data/' + filename + '.csv', 'rU', 'utf-8'), delimiter=',')
    for row in csv_reader:
        dataset.append(row)
    return dataset


def getScores(x, y):
    clf = svm.LinearSVC()
    clf.fit(x, y)
    f1_score = cross_val_score(clf, x, y, cv=5, scoring='f1')
    f1_mean = np.mean(f1_score)
    print('f1', f1_mean)
    precision = cross_val_score(clf, x, y, cv=5, scoring='precision')
    p_mean = np.mean(precision)
    print('precision', p_mean)
    recall = cross_val_score(clf, x, y, cv=5, scoring='recall')
    r_mean = np.mean(recall)
    print('recall', r_mean)
    return round(p_mean, 3), round(r_mean, 3), round(f1_mean, 3)


def create_table(matrix):
    table_string = ''
    for row in matrix:
        for element in row[:-1]:
            table_string += str(element) + ' & '
        table_string += str(row[-1]) + ' \\\\ \n'
    return table_string



data = loadDataset('train')
users = combineAllTweetsPerUser(data)


for user in users:
    f = open("liwc_files/" + user[1] + ".txt", "w")
    f.write(user[5])
    f.close()


liwc_results_train = []
f = open("liwc_results_train.txt", "r")
for line in f.readlines():
    liwc_results_train.append(line)

f.close()

feature_names = liwc_results_train[0].split('\t')[1:]
features = []
for line in liwc_results_train[1:]:
    features.append(line.split('\t'))


###
# Finn label til hver bruker

userlabels = {}
for user in users:
    userlabels[user[1]] = user[-1]


labels = {'unrelated': 0, 'pro_ed': 1, 'pro_recovery': 0}
y = []
x = []
for line in features:
    y.append(labels[userlabels[line[0][:-4]]])
    x.append([float(f.replace(',', '.')) for f in line[1:]])




getScores(mostImportantFeatures, y)




def findBestFeatures(n, weights):
    features = []
    for i in range(len(weights[0].tolist())):
        features.append((abs(weights[0][i]), i))
    features.sort()
    return features[-n:]



clf = svm.SVC(kernel='linear').fit(x, y)
features = findBestFeatures(15, clf.coef_)
imp = [i[1] for i in features]


mostImportantFeatures = []
for val in x:
    mostImportantFeatures.append([val[i] for i in imp])


latexTable = []
for n in range(90, 91, 10):
    features = findBestFeatures(n, clf.coef_)
    imp = [i[1] for i in features]
    mostImportantFeatures = []
    for val in x:
        mostImportantFeatures.append([val[i] for i in imp])
    latexTable.append([n] + list(getScores(mostImportantFeatures, y)))



latexTable.append(['all'] + list(getScores(x, y)))

print(create_table(latexTable))


def create_table(matrix):
    table_string = ''
    for row in matrix:
        for element in row[:-1]:
            table_string += str(element) + ' & '
        table_string += str(row[-1]) + ' \\\\ \n'
    return table_string

