# -*- coding: utf-8 -*-
import csv
import codecs
import gensim
import nltk
import numpy as np
from nltk.stem import WordNetLemmatizer, SnowballStemmer
from nltk.stem.porter import *
from gensim import models
from sklearn import svm
from sklearn.model_selection import cross_val_score
from sklearn.gaussian_process import GaussianProcessRegressor
from sklearn.gaussian_process.kernels import DotProduct, RBF, WhiteKernel
import pyLDAvis
import pyLDAvis.gensim  # don't skip this
import matplotlib.pyplot as plt
from scipy.stats import pearsonr
#matplotlib inline

np.random.seed(0)

nltk.download('wordnet')

# NOTE: all functions take as input a tokenized text.
#stop_words = set(stopwords.words('english'))
#stop_words = gensim.parsing.preprocessing.STOPWORDS

def removeStopWords(tokens):
    filtered_sentence = [w for w in tokens if w not in gensim.parsing.preprocessing.STOPWORDS]
    return filtered_sentence


def lemmatize_stemming(tokens):
    stemmer = SnowballStemmer("english")
    newTokens = []
    for w in tokens:
        newTokens.append(stemmer.stem(WordNetLemmatizer().lemmatize(w, pos='v')))
    return newTokens


def preprocess(text):
    word_tokens = gensim.utils.simple_preprocess(text)
    text_stopwords_removed = removeStopWords(word_tokens)
    lemmatizedStemmed = lemmatize_stemming(text_stopwords_removed)
    return lemmatizedStemmed


# Follows this tutorial: https://towardsdatascience.com/topic-modeling-and-latent-dirichlet-allocation-in-python-9bf156893c24
# and https://www.machinelearningplus.com/nlp/topic-modeling-gensim-python/

combined_df = pd.concat([essays_df, mypersonality_df], ignore_index=True)



train = combined_df.head(int(combined_df.shape[0]*0.8))
test = combined_df.tail(int(combined_df.shape[0]*0.2))

y_train_extr = pd.to_numeric(train.sEXT)
y_test_extr = pd.to_numeric(test.sEXT)

y_train_agr = pd.to_numeric(train.sAGR)
y_test_agr = pd.to_numeric(test.sAGR)

y_train_cons = pd.to_numeric(train.sCON)
y_test_cons = pd.to_numeric(test.sCON)

y_train_emot = pd.to_numeric(train.sNEU)
y_test_emot = pd.to_numeric(test.sNEU)

y_train_open = pd.to_numeric(train.sOPN)
y_test_open = pd.to_numeric(test.sOPN)



y_train = [y_train_extr, y_train_agr, y_train_cons, y_train_emot, y_train_open]
y_test = [y_test_extr, y_test_agr, y_test_cons, y_test_emot, y_test_open]



text_train = train.TEXT
text_test = test.TEXT




processed_docs = []
#for doc in exampleTweets:
#    processed_docs.append(preprocess(doc))
count = 0
for text in text_train:
    count += 1
    processed_docs.append(preprocess(text))
    if count % 500 == 0:
        count


#test:
processed_docs_test = []
#for doc in exampleTweets:
#    processed_docs.append(preprocess(doc))
count = 0
for text in text_test:
    count += 1
    processed_docs_test.append(preprocess(text))
    if count % 500 == 0:
        count




# Dictionary of the words in the texts
dictionary = gensim.corpora.Dictionary(processed_docs)

# Filters out words that appear in less than 15 documents and more than 50% of all documents
# Kan teste ut verdier for parameterene
dictionary.filter_extremes(no_below=10, no_above=0.5, keep_n=10000)

# Counts how many times the word is in the document
bow_corpus = [dictionary.doc2bow(doc) for doc in processed_docs]




# Counts how many times the word is in the document
bow_corpus_test = [dictionary.doc2bow(doc) for doc in processed_docs_test]



train = bow_corpus#[:int(len(bow_corpus)*0.8)]
test = bow_corpus_test

# TF-IDF
tfidf = models.TfidfModel(train)
corpus_tfidf = tfidf[train]
corpus_tfidf_test = tfidf[test]

# LDA using BoW
lda_model = gensim.models.LdaMulticore(train, num_topics=10, id2word=dictionary, passes=2, workers=2)
#for idx, topic in lda_model.print_topics(-1):
#    print('Topic: {} \nWords: {}'.format(idx, topic))


# LDA using TF-IDF
lda_model_tfidf = gensim.models.LdaMulticore(corpus_tfidf, num_topics=5, id2word=dictionary, passes=2, workers=4)
#for idx, topic in lda_model_tfidf.print_topics(-1):
#    print('Topic: {} Word: {}'.format(idx, topic))


# Saving the model to a file that can be loaded at a later time
#temp_file = datapath("bow_model")
#lda_model.save(temp_file)

# a measure of how good the model is. lower the better.
#lda_model.log_perplexity(train)

# Compute Coherence Score another perfomrnace model, higher is better
#coherence_model_lda = models.CoherenceModel(model=lda_model, texts=processed_docs, dictionary=dictionary, coherence='c_v')
#coherence_lda = coherence_model_lda.get_coherence()
#print('\nCoherence Score: ', coherence_lda)

# Visualize the topics
#vis = pyLDAvis.gensim.prepare(lda_model, train, dictionary)
#pyLDAvis.save_html(vis, 'LDA_Visualization.html')

# Running the LDA on one instance (just an example)
#for index, score in sorted(lda_model[bow_corpus[2]], key=lambda tup: -1*tup[1]):
#    print("\nScore: {}\t \nTopic: {}".format(score, lda_model.print_topic(index, 10)))

# creating a feature set from the data

def createX(lda, corpus, num_topics):
    featureset = []
    for i in range(len(corpus)):
        featureset.append(lda[corpus[i]])
    X = []
    for i in range(len(featureset)):
        row = featureset[i]
        X.append([0]*num_topics)
        for a, b in row[0:-1]:
            X[i][a] = b
    X = np.array(X)
    return X


def create_table(matrix):
    table_string = ''
    for row in matrix:
        for element in row[:-1]:
            table_string += str(element) + ' & '
        table_string += str(row[-1]) + ' \\\\ \n'
    return table_string





def get_pearsonvalue_GPR(x_train, y_train, X_test, y_test):
    clf = GaussianProcessRegressor(kernel=DotProduct() + WhiteKernel())
    clf.fit(x_train, y_train.values)
    y_pred = clf.predict(X_test)
    return pearsonr(y_test.values, y_pred)


latex_table = []
for kernel in [DotProduct() + WhiteKernel()]:
    latex_table.append([str(kernel)])
    for j in range(len(y_train)):
        pearson = get_pearsonvalue_GPR(emb_avg, y_train[j], emb_avg_test, y_test[j], kernel)
        print(pearson)
        latex_table[-1].append(str(pearson[0])[:6])


print(create_table(latex_table))



"""
SVR
"""
def get_pearsonvalue(x_train, y_train, X_test, y_test):
    clf = svm.SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2)
    clf.fit(x_train, y_train)
    y_pred = clf.predict(X_test)
    return pearsonr(y_test.values, y_pred)




dictionary = gensim.corpora.Dictionary(processed_docs)
dictionary.filter_extremes(no_below=10, no_above=0.5, keep_n=10000)
bow_corpus = [dictionary.doc2bow(doc) for doc in processed_docs]
bow_corpus_test = [dictionary.doc2bow(doc) for doc in processed_docs_test]
tfidf = models.TfidfModel(bow_corpus)
corpus_tfidf = tfidf[bow_corpus]
corpus_tfidf_test = tfidf[bow_corpus_test]


numTopics = [5, 10, 15, 20]
y_train = [y_train_extr, y_train_agr, y_train_cons, y_train_emot, y_train_open]
y_test = [y_test_extr, y_test_agr, y_test_cons, y_test_emot, y_test_open]


latex_table = []
for i in range(len(numTopics)):
    print(i)
    latex_table.append(["BoW", numTopics[i]])
    lda_model = gensim.models.LdaMulticore(bow_corpus, num_topics=numTopics[i], id2word=dictionary, passes=2, workers=2)
    lda_model_tfidf = gensim.models.LdaMulticore(corpus_tfidf, num_topics=numTopics[i], id2word=dictionary, passes=2, workers=4)
    X_bow = createX(lda_model, bow_corpus, numTopics[i])
    X_test_bow = createX(lda_model, bow_corpus_test, numTopics[i])
    for j in range(len(y_train)):
        pearson = get_pearsonvalue_GPR(X_bow, y_train[j], X_test_bow, y_test[j])
        latex_table[-1].append(str(pearson[0])[:6])
    latex_table.append(["TF-IDF", numTopics[i]])
    X_tf = createX(lda_model_tfidf, corpus_tfidf, numTopics[i])
    X_test_tf = createX(lda_model_tfidf, corpus_tfidf_test, numTopics[i])
    for j in range(len(y_train)):
        pearson = get_pearsonvalue_GPR(X_tf, y_train[j], X_test_tf, y_test[j])
        latex_table[-1].append(str(pearson[0])[:6])


print(create_table(latex_table))

latex_table = [[]]
X = createX(lda_model, corpus_tfidf)
X_test = createX(lda_model, corpus_tfidf_test)


# extr
clf = svm.SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2)
clf.fit(X, y_train_extr)
y_pred = clf.predict(X_test)
pearson = pearsonr(y_test_extr.values, y_pred)
latex_table[0].append(str(pearson[0])[:6])

# agr
clf = svm.SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2).fit(X, y_train_agr)
y_pred = clf.predict(X_test)
pearson = pearsonr(y_test_agr.values, y_pred)
latex_table[0].append(str(pearson[0])[:6])


# cons
clf = svm.SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2).fit(X, y_train_cons)
y_pred = clf.predict(X_test)
pearson = pearsonr(y_test_cons.values, y_pred)
latex_table[0].append(str(pearson[0])[:6])


# emot
clf = svm.SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2).fit(X, y_train_emot)
y_pred = clf.predict(X_test)
pearson = pearsonr(y_test_emot.values, y_pred)
latex_table[0].append(str(pearson[0])[:6])

# open
clf = svm.SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2).fit(X, y_train_open)
y_pred = clf.predict(X_test)
pearson = pearsonr(y_test_open.values, y_pred)
latex_table[0].append(str(pearson[0])[:6])


print(create_table(latex_table))

