import gensim
import numpy as np
import matplotlib.pyplot as plt
import pandas as pd
from keras.preprocessing.text import Tokenizer
from keras.preprocessing.sequence import pad_sequences
from sklearn.gaussian_process import GaussianProcessRegressor
from sklearn.gaussian_process.kernels import DotProduct, RBF, WhiteKernel
from sklearn.svm import SVR
from scipy.stats import pearsonr
from sklearn.neighbors import KNeighborsRegressor
from sklearn.neural_network import MLPRegressor
from sklearn.linear_model import Ridge



#combined_df = pd.concat([essays_df, mypersonality_df, youtube_df], ignore_index=True)
combined_df = pd.concat([essays_df, mypersonality_df], ignore_index=True)
#combined_df = essays_df

# combined_df is from the preprocess code and has all the data
train = combined_df.head(int(combined_df.shape[0]*0.8))
test = combined_df.tail(int(combined_df.shape[0]*0.2))


# Preprocess the transcripts and store them as the x vectors
#X_train = [gensim.utils.simple_preprocess(text) for text
#           in train['text'].values.tolist()]
#X_test = [gensim.utils.simple_preprocess(text) for text
#          in test['text'].values.tolist()]


"""
GLOVE MODEL
https://towardsdatascience.com/word-embeddings-for-sentiment-analysis-65f42ea5d26e
"""
NB_WORDS = 10000  # Parameter indicating the number of words we'll put in the dictionary
NB_START_EPOCHS = 10  # Number of epochs we usually start to train with
BATCH_SIZE = 512  # Size of the batches used in the mini-batch gradient descent
#MAX_LEN = 24  # Maximum number of words in a sequence
GLOVE_DIM = 100  # Number of dimensions of the GloVe word embeddings (25, 50, 100 el 200)


# This only removes stop words, leaving the text as a whole text
X_train = [gensim.parsing.preprocessing.remove_stopwords(text) for text
           in train['TEXT'].values.tolist()]
X_test = [gensim.parsing.preprocessing.remove_stopwords(text) for text
          in test['TEXT'].values.tolist()]
# Using keras tokenizer
tk = Tokenizer(num_words=NB_WORDS,
               filters='!"#$%&()*+,-./:;<=>?@[\]^_`{"}~\t\n',
               lower=True,
               split=" ")


# Fits the tokenizer on only the training data.
# This creates an index for each word in the training data
tk.fit_on_texts(X_train)
# Now X_train_seq will have a sequence of word indices representing the text
X_train_seq = tk.texts_to_sequences(X_train)
X_test_seq = tk.texts_to_sequences(X_test)

# This is a dictionary of all the words with their respective indices as values
# tk.word_index

# This makes all the sequences the same length (padding first)
# uses 0.0 as the padding since 0 is not in the indices for this reason
# fix the maxlen so that we pad all to be full length
X_train_seq_trunc = pad_sequences(X_train_seq, maxlen=677) #, maxlen=MAX_LEN (possible arg)
X_test_seq_trunc = pad_sequences(X_test_seq, maxlen=677)


# At this point we have a sequence of integers for each text,
# where each integer is the index of a word and the text could
# be reproduced by replacing the words for the indices.
glove_file = 'glove.twitter.27B.' + str(GLOVE_DIM) + 'd.txt'
# This is the dictionary that will hold the pretrained values from the model
emb_dict = {}
glove = open('glove.twitter.27B/' + glove_file)
for line in glove:
    values = line.split()
    word = values[0]
    vector = np.asarray(values[1:], dtype='float32')
    emb_dict[word] = vector


glove.close()


# Start by initializing an empty matrix to ensure no missing values
emb_matrix = np.zeros((NB_WORDS, GLOVE_DIM))
# Loop through word : index pairs
# This essentially combines the trained glove values with the word indices
# replacing the word string as a key and using the index instead
for w, i in tk.word_index.items():
    # Since we are only keeping the first NB_WORDS words
    if i < NB_WORDS:
        # This was created by the GloVe model
        vect = emb_dict.get(w)
        if vect is not None:
            # Word i in the emb matrix now has the values of the pretrained model
            emb_matrix[i] = vect
    else:
        break


# We now have a matrix of words and embeddings and we need to find a representation
# of the whole text for each transcript.


##
# Average as a feature for the entire doc
##
def document_avg_embedding(dataset):
    emb_avg = []
    # Averaging the word vectors for each text
    for vlog_index in range(len(dataset)):
        emb_total = np.zeros(GLOVE_DIM)
        for word_index in range(len(dataset[vlog_index])):
            emb_total = np.add(emb_total, emb_matrix[dataset[vlog_index, word_index]])
        emb_avg.append(emb_total / np.sqrt(emb_total.dot(emb_total)))
    return emb_avg


emb_avg = document_avg_embedding(X_train_seq_trunc)
emb_avg_test = document_avg_embedding(X_test_seq_trunc)



#####
# Labels
#####
y_train_extr = pd.to_numeric(train.sEXT)
y_test_extr = pd.to_numeric(test.sEXT)

y_train_agr = pd.to_numeric(train.sAGR)
y_test_agr = pd.to_numeric(test.sAGR)

y_train_cons = pd.to_numeric(train.sCON)
y_test_cons = pd.to_numeric(test.sCON)

y_train_emot = pd.to_numeric(train.sNEU)
y_test_emot = pd.to_numeric(test.sNEU)

y_train_open = pd.to_numeric(train.sOPN)
y_test_open = pd.to_numeric(test.sOPN)


y_train = [y_train_extr, y_train_agr, y_train_cons, y_train_emot, y_train_open]
y_test = [y_test_extr, y_test_agr, y_test_cons, y_test_emot, y_test_open]



####
# GP
####

extr_proED = gpr_extr.predict(emb_avg)
agr_proED = gpr_agr.predict(emb_avg)
cons_proED = gpr_cons.predict(emb_avg)
emot_proED = gpr_emot.predict(emb_avg)
open_proED = gpr_open.predict(emb_avg)


features = []
for i in range(len(extr_proED)):
    features.append([extr_proED[i], agr_proED[i], cons_proED[i], emot_proED[i], open_proED[i]])


getScores(features, y)


kernel = DotProduct() + WhiteKernel()
kernel = RBF(length_scale=1.0) + WhiteKernel()

results = ""

# extr
gpr_extr = GaussianProcessRegressor(kernel=kernel).fit(emb_avg, y_train_extr.values)
y_pred = gpr.predict(emb_avg_test)
pearson = pearsonr(y_test_extr.values, y_pred)
results += ("Extr: " + str(pearson) + " " + str(GLOVE_DIM))

# agr
gpr_agr = GaussianProcessRegressor(kernel=kernel).fit(emb_avg, y_train_agr.values)
y_pred = gpr.predict(emb_avg_test)
pearson = pearsonr(y_test_agr.values, y_pred)
results += ("Agr: " + str(pearson) + " " + str(GLOVE_DIM))

# cons
gpr_cons = GaussianProcessRegressor(kernel=kernel).fit(emb_avg, y_train_cons.values)
y_pred = gpr.predict(emb_avg_test)
pearson = pearsonr(y_test_cons.values, y_pred)
results += ("Cons: " + str(pearson) + " " + str(GLOVE_DIM))

# emot
gpr_emot = GaussianProcessRegressor(kernel=kernel).fit(emb_avg, y_train_emot.values)
y_pred = gpr.predict(emb_avg_test)
pearson = pearsonr(y_test_emot.values, y_pred)
results += ("Emot: " + str(pearson) + " " + str(GLOVE_DIM))
# open
gpr_open = GaussianProcessRegressor(kernel=kernel).fit(emb_avg, y_train_open.values)
y_pred = gpr.predict(emb_avg_test)
pearson = pearsonr(y_test_open.values, y_pred)
results += ("Open: " + str(pearson) + " " + str(GLOVE_DIM))

results


def get_pearsonvalue_GPR(x_train, y_train, X_test, y_test, kernel):
    clf = GaussianProcessRegressor(kernel=kernel)
    clf.fit(x_train, y_train.values)
    y_pred = clf.predict(X_test)
    return pearsonr(y_test.values, y_pred)


latex_table = []
for kernel in [DotProduct() + WhiteKernel()]:
    latex_table.append([str(kernel)])
    for j in range(len(y_train)):
        pearson = get_pearsonvalue_GPR(emb_avg, y_train[j], emb_avg_test, y_test[j], kernel)
        print(pearson)
        latex_table[-1].append(str(pearson[0])[:6])


print(create_table(latex_table))



"""
Results:

uten avg labels:
'Extr: (0.16771262653635574, 0.00010955969991342871) 25
Cons: (0.24292828963752436, 1.6198115890154482e-08) 25
Emot: (0.06594214990166135, 0.13057176608982712) 25
Open: (0.0919651912673705, 0.03480166579492281) 25
Agr: (0.3034307128682947, 1.0978338154586616e-12) 25'
med:
'Extr: (0.1688252433535773, 0.00016583097379637468) 25
Cons: (0.2044839825118734, 4.712215135439431e-06) 25
Emot: (0.08054456475633663, 0.07397892713791042) 25
Open: (0.2817291418716034, 1.9028886607173323e-10) 25
Agr: (0.27408038077900865, 6.053607382040021e-10) 25'

essay + twitter
uten avg labels
Extr: (0.1919601373224921, 9.09674272212983e-06) 200
Agr: (0.3062434849759186, 6.624473623860747e-13) 200
Cons: (0.24303972161929016, 1.5948347481758594e-08) 200
Emot: (0.1308298810153308, 0.002619317042116267) 200
Open: (0.19886645478964657, 4.215557374919702e-06) 200
med avg labels
Extr: (0.1954834181209837, 6.165252171324098e-06) 200
Agr: (0.4154701932474777, 2.0770136007217864e-23) 200
Cons: (0.1550594239310374, 0.0003531873617236342) 200
Emot: (0.21293802268020537, 8.081434699143809e-07) 200
Open: (0.2516698612786939, 4.6766421386942355e-09) 200

Dot + white
Extr: (0.17377399556285963, 0.12317713335517129) 25
Agr: (0.3704043989341789, 0.0007195909536663356) 25
Cons: (0.34054532029014184, 0.001995238260975627) 25
Emot: (0.15509419806373628, 0.16953476034963721) 25
Open: (0.15750901146982696, 0.16290796777956076) 25

RBF
Extr: (0.15903549976034198, 0.15881894886757475) 25
Agr: (0.4056165457552128, 0.0001894817894878602) 25
Cons: (0.025012454320178634, 0.825690763231884) 25
Emot: (0.17539064832578205, 0.11967452409006653) 25
Open: (0.16776236071740033, 0.13689326522193557) 25

Dot + white
Extr: (0.20816796812133714, 0.06388775724708787) 50
Agr: (0.40051220043134717, 0.00023207106268891646) 50
Cons: (0.3523427019097649, 0.001349201302661545) 50
Emot: (0.1656046910909598, 0.14208823443199056) 50
Open: (0.2205048758882599, 0.04935868334047747) 50


RBF
Extr: (0.18807705787664525, 0.09478449678410973) 50
Agr: (0.4310397267269785, 6.56694415097208e-05) 50
Cons: (0.3944654877076944, 0.0002938434877764328) 50
Emot: (0.18530060351418734, 0.09985044571612267) 50
Open: (0.2100843326242496, 0.06142692691237819) 50


Dot + white
Extr: (0.27721398235650035, 0.01279404412789249) 100
Agr: (0.42633566612675383, 8.040835625776134e-05) 100
Cons: (0.3423847335662918, 0.001879004448311762) 100
Emot: (0.16164214162260998, 0.15201338649802792) 100
Open: (0.26898493107627475, 0.01583677027735261) 100


RBF
Extr: (0.2487288943180072, 0.026096395833466676) 100
Agr: (0.4521497617777411, 2.5492307104300827e-05) 100
Cons: (0.37720508609033715, 0.0005625241906439901) 100
Emot: (0.1752188543113062, 0.12004305584918441) 100
Open: (0.23040762822599403, 0.039768318913716114) 100

Dot-kernel
trait - pearson, p-score, glove dimension
Extr: (0.1122893035440316, 0.32135373431525593) 200
Agr: (0.4470752017838274, 3.218745394234958e-05) 200
Cons: (0.1125711189578575, 0.3201330003166311) 200
Emot: (0.13810548082085233, 0.2218302009791983) 200
Open: (0.0018813066703100136, 0.9867859618256359) 200

Dot-product + whitekernel
Extr: (0.2763775357885864, 0.01307820876255076) 200
Agr: (0.44416790858447486, 3.672741167085186e-05) 200
Cons: (0.35431645173742016, 0.0012618567653890499) 200
Emot: (0.18154315135601137, 0.10704061722705364) 200
Open: (0.27548804244188935, 0.013386384149677187) 200

RBF(1.0) + white, RBF(10.0) + white = samme 100 og 0.1 også
Extr: (0.2055455782759559, 0.06738394594538995) 200
Agr: (0.46858223734681664, 1.1673499104418878e-05) 200
Cons: (0.39024486929757435, 0.0003455477199948934) 200
Emot: (0.19971292542894775, 0.07571434309550083) 200
Open: (0.21150991629311, 0.059646694116797974) 200
"""


######
# SVM
######

results = ""


latex_table.append(["SVR"])
# extr
clf = SVR(kernel='linear', gamma='scale', C=C_extr, epsilon=0.ep_extr).fit(emb_avg, y_train_extr)
y_pred = clf.predict(emb_avg_test)
pearson = pearsonr(y_test_extr.values, y_pred)
results += (" Extr: " + str(pearson) + " " + str(GLOVE_DIM))
latex_table[-1].append(str(pearson[0])[:6])

# agr
clf = SVR(kernel='linear', gamma='scale', C=C_agr, epsilon=ep_agr).fit(emb_avg, y_train_agr)
y_pred = clf.predict(emb_avg_test)
pearson = pearsonr(y_test_agr.values, y_pred)
results += (" Agr: " + str(pearson) + " " + str(GLOVE_DIM))
latex_table[-1].append(str(pearson[0])[:6])

# cons
clf = SVR(kernel='linear', gamma='scale', C=C_cons, epsilon=ep_cons).fit(emb_avg, y_train_cons)
y_pred = clf.predict(emb_avg_test)
pearson = pearsonr(y_test_cons.values, y_pred)
results += (" Cons: " + str(pearson) + " " + str(GLOVE_DIM))
latex_table[-1].append(str(pearson[0])[:6])

# emot
clf = SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2).fit(emb_avg, y_train_emot)
y_pred = clf.predict(emb_avg_test)
pearson = pearsonr(y_test_emot.values, y_pred)
results += (" Emot: " + str(pearson) + " " + str(GLOVE_DIM))
latex_table[-1].append(str(pearson[0])[:6])

# open
clf = SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2).fit(emb_avg, y_train_open)
y_pred = clf.predict(emb_avg_test)
pearson = pearsonr(y_test_open.values, y_pred)
results += (" Open: " + str(pearson) + " " + str(GLOVE_DIM))
latex_table[-1].append(str(pearson[0])[:6])

results


def get_pearsonvalue_SVR(x_train, y_train, X_test, y_test, C, ep):
    print(len(y_train))
    print(len(y_test))
    clf = SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2)
    clf.fit(x_train, y_train.values)
    y_pred = clf.predict(X_test)
    return pearsonr(y_test.values, y_pred)


latex_table.append(["SVR"])
for j in range(len(y_train)):
    print(len(y_train[j]))
    print(len(y_test[j]))
    pearson = get_pearsonvalue_SVR(emb_avg, y_train[j], emb_avg_test, y_test[j], c_values[j], epsilon_values[j])
    print(pearson)
    latex_table[-1].append(str(pearson[0])[:6])


print(create_table(latex_table))





def svr_find_optimal_C(X, y, X_test, y_test):
    C_values = [0.01, 0.1, 0.5, 1, 1.5, 2, 3, 5, 7, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 25, 30, 35, 40]
    results = []
    for C in C_values:
        clf = SVR(kernel='linear', gamma='scale', C=C, epsilon=0.2).fit(X, y)
        y_pred = clf.predict(X_test)
        pearson = pearsonr(y_test, y_pred)
        results.append(pearson[0])
    plt.plot(C_values, results, 'b', label='C')
    plt.legend()
    plt.show()
    return C_values[np.argmax(results)]


def svr_find_optimal_epsilon(X, y, X_test, y_test, C):
    epsilon_values = [0.01, 0.05, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 1.0, 1.5, 2.0, 3.0, 5.0]
    results = []
    for epsilon in epsilon_values:
        clf = SVR(kernel='linear', gamma='scale', C=C, epsilon=epsilon).fit(X, y)
        y_pred = clf.predict(X_test)
        pearson = pearsonr(y_test, y_pred)
        results.append(pearson[0])
    plt.plot(epsilon_values, results, 'b', label='epsilon')
    plt.legend()
    plt.show()
    return epsilon_values[np.argmax(results)]


C_extr = svr_find_optimal_C(emb_avg, y_train_extr, emb_avg_test, y_test_extr)
ep_extr = svr_find_optimal_epsilon(emb_avg, y_train_extr, emb_avg_test, y_test_extr, C_extr)

C_agr = svr_find_optimal_C(emb_avg, y_train_agr, emb_avg_test, y_test_agr)
ep_agr = svr_find_optimal_epsilon(emb_avg, y_train_agr, emb_avg_test, y_test_agr, C_agr)

C_cons = svr_find_optimal_C(emb_avg, y_train_cons, emb_avg_test, y_test_cons)
ep_cons = svr_find_optimal_epsilon(emb_avg, y_train_cons, emb_avg_test, y_test_cons, C_cons)

C_emot = svr_find_optimal_C(emb_avg, y_train_emot, emb_avg_test, y_test_emot)
ep_emot = svr_find_optimal_epsilon(emb_avg, y_train_emot, emb_avg_test, y_test_emot, C_emot)

C_open = svr_find_optimal_C(emb_avg, y_train_open, emb_avg_test, y_test_open)
ep_open = svr_find_optimal_epsilon(emb_avg, y_train_open, emb_avg_test, y_test_open, C_open)


c_values = [C_extr, C_agr, C_cons, C_emot, C_open]
epsilon_values = [ep_extr, ep_agr, ep_cons, ep_emot, ep_open]

# Final SVM models to be used on pro-ed:
clf_extr = SVR(kernel='linear', gamma='scale', C=C_extr, epsilon=ep_extr).fit(emb_avg + emb_avg_test, y_train_extr.values.tolist() + y_test_extr.values.tolist())
clf_agr = SVR(kernel='linear', gamma='scale', C=C_agr, epsilon=ep_agr).fit(emb_avg + emb_avg_test, y_train_agr.values.tolist() + y_test_agr.values.tolist())
clf_cons = SVR(kernel='linear', gamma='scale', C=C_cons, epsilon=ep_cons).fit(emb_avg + emb_avg_test, y_train_cons.values.tolist() + y_test_cons.values.tolist())
clf_emot = SVR(kernel='linear', gamma='scale', C=C_emot, epsilon=ep_emot).fit(emb_avg + emb_avg_test, y_train_emot.values.tolist() + y_test_emot.values.tolist())
clf_open = SVR(kernel='linear', gamma='scale', C=C_open, epsilon=ep_open).fit(emb_avg + emb_avg_test, y_train_open.values.tolist() + y_test_open.values.tolist())



"""

SVR(gamma='scale', C=1.0, epsilon=0.2)
Extr: (0.280170941065157, 0.011831991623662063) 200
Agr: (0.3428860632337819, 0.0018484010416350014) 200
Cons: (0.3870837109018326, 0.00038959974419951334) 200
Emot: (0.10421506395895047, 0.35759060167019663) 200
Open: (0.20899457248941505, 0.06281668582895772) 200

SVR(gamma='scale', C=0.10, epsilon=0.2)
Extr: (0.2829150378403865, 0.01099610770733518) 200
Agr: (0.32983771163556835, 0.00280974868677614) 200
Cons: (0.38758493230804564, 0.00038228822082518344) 200
Emot: (0.10183079031171066, 0.36875546523378) 200
Open: (0.20918365947399645, 0.06257373408836152) 200

SVR(gamma='scale', C=10, epsilon=0.2)
Extr: (0.29036864200993834, 0.008980011484231738) 200
Agr: (0.46584280938832984, 1.3334241032274626e-05) 200
Cons: (0.35660728491448934, 0.0011669200899997578) 200
Emot: (0.14333486791891834, 0.20465162154794073) 200
Open: (0.23568506464989664, 0.03532616243557588) 200

SVR(gamma='scale', C=15, epsilon=0.2)
Extr: (0.2879864916995781, 0.009585938697793728) 200
Agr: (0.509769565260051, 1.3675591283962653e-06) 200
Cons: (0.3398912015371275, 0.002038106837427877) 200
Emot: (0.16592902576712243, 0.14129799911183868) 200
Open: (0.2840111779542992, 0.010676876566823547) 200

SVR(gamma='scale', C=25, epsilon=0.2)
Extr: (0.2617824781526149, 0.018993049889743322) 200
Agr: (0.5507832601945234, 1.1997701174560777e-07) 200
Cons: (0.3415711661430421, 0.0019296404582234872) 200
Emot: (0.1738517263566396, 0.12300694661939766) 200
Open: (0.2763339225898464, 0.013093174360546713) 200

SVR(gamma='scale', C=50, epsilon=0.2)
Extr: (0.2574955748713745, 0.021116601061184227) 200
Agr: (0.5577872195926205, 7.658939825679491e-08) 200
Cons: (0.338145206099468, 0.002156619993515828) 200
Emot: (0.17586810773259823, 0.1186548440516635) 200
Open: (0.2407017741303915, 0.03149612496119219) 200

SVR(gamma='scale', C=100, epsilon=0.2)
Extr: (0.2382689872791047, 0.033307426710533064) 200
Agr: (0.576361451599775, 2.2125372932626153e-08) 200
Cons: (0.3097551620645286, 0.005173099310413088) 200
Emot: (0.18436000972362873, 0.10161387639920184) 200
Open: (0.19610899904835352, 0.08126059245420983) 200


#Epsilon:
SVR(gamma='scale', C=15, epsilon=0.1)
Extr: (0.2844916994874984, 0.010539500561399996) 200
Agr: (0.5021535996768393, 2.076767875691072e-06) 200
Cons: (0.3314307290792626, 0.0026722523883911525) 200
Emot: (0.1734377224466456, 0.12391546031715854) 200
Open: (0.21521098690160864, 0.05522013790765652) 200

SVR(gamma='scale', C=15, epsilon=0.2)
Extr: (0.2879864916995781, 0.009585938697793728) 200
Agr: (0.509769565260051, 1.3675591283962653e-06) 200
Cons: (0.3398912015371275, 0.002038106837427877) 200
Emot: (0.16592902576712243, 0.14129799911183868) 200
Open: (0.2840111779542992, 0.010676876566823547) 200

SVR(gamma='scale', C=15, epsilon=0.5)
Extr: (0.23433047406056262, 0.03642473185762346) 200
Agr: (0.44595507624943176, 3.3870869821061755e-05) 200
Cons: (0.3727300887360528, 0.0006618710256147878) 200
Emot: (0.12862425618157095, 0.2555070949129544) 200
Open: (0.29672688943110404, 0.007523959764775224) 200


Glove dimensions:
SVR(gamma='scale', C=15, epsilon=0.2)

Extr: (0.26506405614655754, 0.017493741434184536) 100
Agr: (0.5039610215459602, 1.8824512784077962e-06) 100
Cons: (0.30339447070596076, 0.006224086858783006) 100
Emot: (0.13567285209866314, 0.23015728852505415) 100
Open: (0.26743179359198416, 0.016476193416764796) 100

Extr: (0.16435036737440856, 0.14517571669531515) 50
Agr: (0.47570993633923103, 8.21396001831994e-06) 50
Cons: (0.2996011280328241, 0.006936912031085185) 50
Emot: (0.14025200591433928, 0.21466020543878508) 50
Open: (0.21290516513285218, 0.057945207614844535) 50

Extr: (0.11966409956285717, 0.29038938281844073) 25
Agr: (0.41648480511699204, 0.00012170579467513051) 25
Cons: (0.26803899111068286, 0.01622361220768487) 25
Emot: (0.15781825606037825, 0.16207336572787293) 25
Open: (0.11072689337344269, 0.3281755855583537) 25

"""

def create_table(matrix):
    table_string = ''
    for row in matrix:
        for element in row[:-1]:
            table_string += str(element) + ' & '
        table_string += str(row[-1]) + ' \\\\ \n'
    return table_string


def get_pearsonvalue_KNN(x_train, y_train, X_test, y_test, n):
    clf = KNeighborsRegressor(n_neighbors=n)
    clf.fit(x_train, y_train)
    y_pred = clf.predict(X_test)
    return pearsonr(y_test.values, y_pred)


latex_table = []

for n in [2, 5, 8, 10, 15]:
    latex_table.append([n, ])
    for j in range(len(y_train)):
        pearson = get_pearsonvalue_KNN(emb_avg, y_train[j], emb_avg_test, y_test[j], n)
        latex_table[-1].append(str(pearson[0])[:6])


print(create_table(latex_table))


kernels = [DotProduct(), RBF() + WhiteKernel(), DotProduct() + WhiteKernel()]


def get_pearsonvalue_RR(x_train, y_train, X_test, y_test, alpha):
    clf = Ridge(alpha=alpha)
    clf.fit(x_train, y_train)
    y_pred = clf.predict(X_test)
    return pearsonr(y_test.values, y_pred)


for alpha in [2, 4, 6]:
    latex_table.append([str(alpha)])
    for j in range(len(y_train)):
        pearson = get_pearsonvalue_RR(emb_avg, y_train[j], emb_avg_test, y_test[j], alpha)
        latex_table[-1].append(str(pearson[0])[:6])


print(create_table(latex_table))


def get_pearsonvalue_MLP(x_train, y_train, X_test, y_test, layerSize):
    clf = MLPRegressor(hidden_layer_sizes=(layerSize, ))
    clf.fit(x_train, y_train)
    y_pred = clf.predict(X_test)
    return pearsonr(y_test.values, y_pred)


for n in [50, 100, 200, 500]:
    latex_table.append([str(n)])
    for j in range(len(y_train)):
        pearson = get_pearsonvalue_MLP(emb_avg, y_train[j], emb_avg_test, y_test[j], n)
        latex_table[-1].append(str(pearson[0])[:6])


print(create_table(latex_table))
