import numpy as np
import pandas as pd
from sklearn.gaussian_process import GaussianProcessRegressor
from sklearn.gaussian_process.kernels import DotProduct, RBF, WhiteKernel
from sklearn.svm import LinearSVR
from scipy.stats import pearsonr
from sklearn.neighbors import KNeighborsRegressor
from sklearn.kernel_ridge import KernelRidge
from sklearn.neural_network import MLPRegressor


def create_table(matrix):
    table_string = ''
    for row in matrix:
        for element in row[:-1]:
            table_string += str(element) + ' & '
        table_string += str(row[-1]) + ' \\\\ \n'
    return table_string


def findBestFeatures(n, weights):
    features = []
    for i in range(len(weights[0].tolist())):
        features.append((abs(weights[0][i]), i))
    features.sort()
    return features[-n:]



combined_df = pd.concat([essays_df, mypersonality_df], ignore_index=True)

# combined_df is from the preprocess code and has all the data
train = combined_df.head(int(combined_df.shape[0]*0.8))
test = combined_df.tail(int(combined_df.shape[0]*0.2)+1)


#####
# Labels
#####
y_train_extr = pd.to_numeric(train.sEXT).values
y_test_extr = pd.to_numeric(test.sEXT).values

y_train_agr = pd.to_numeric(train.sAGR).values
y_test_agr = pd.to_numeric(test.sAGR).values

y_train_cons = pd.to_numeric(train.sCON).values
y_test_cons = pd.to_numeric(test.sCON).values

y_train_emot = pd.to_numeric(train.sNEU).values
y_test_emot = pd.to_numeric(test.sNEU).values

y_train_open = pd.to_numeric(train.sOPN).values
y_test_open = pd.to_numeric(test.sOPN).values


y_train = [y_train_extr, y_train_agr, y_train_cons, y_train_emot, y_train_open]
y_test = [y_test_extr, y_test_agr, y_test_cons, y_test_emot, y_test_open]


X = combined_df['TEXT'].values.tolist()

for i in range(len(X)):
    f = open("liwc_files_personality/" + str(i) + ".txt", "w")
    f.write(X[i])
    f.close()




liwc_results_raw = []
f = open("liwc_results.txt", "r")
for line in f.readlines():
    liwc_results_raw.append(line.split('\t'))

f.close()


liwc_results = [[]] * len(combined_df['TEXT'].values)
for res in liwc_results_raw[1:]:
    liwc_results[int(res[0][:-4])] = [float(r.replace(',', '.')) for r in res[1:]]


X_train = liwc_results[:int(len(X)*0.8)]
X_test = liwc_results[int(len(X)*0.8):]



def get_pearsonvalue(X_train, y_train, X_test, y_test, n, features_ranked):
    features = features_ranked[-n:]
    imp = [i[1] for i in features[0]]
    X_imp_train = []
    for val in X_train:
        X_imp_train.append([val[i] for i in imp])
    clf_features = GaussianProcessRegressor(kernel=DotProduct() + WhiteKernel()).fit(X_imp_train, y_train)
    X_imp_test = []
    for val in X_test:
        X_imp_test.append([val[i] for i in imp])
    y_pred = clf_features.predict(X_imp_test)
    return pearsonr(y_test, y_pred)


features_ranked = []
for i in range(len(y_train)):
    clf = LinearSVR(epsilon=0.8).fit(X_train, y_train[i])
    weights = clf.coef_
    features = []
    for j in range(len(weights.tolist())):
        features.append((abs(weights[j]), j))
    features.sort()
    features_ranked.append(features)




latex_table = []
for n in range(10, 91, 10):
    latex_table.append([n])
    for j in range(len(y_train)):
        pearson = get_pearsonvalue(X_train, y_train[j], X_test, y_test[j], n, features_ranked)
        print(pearson)
        latex_table[-1].append(str(pearson[0])[:6])


print(create_table(latex_table))



def get_pearsonvalue_GPR(x_train, y_train, X_test, y_test, kernel):
    clf = GaussianProcessRegressor(kernel=DotProduct() + WhiteKernel())
    clf.fit(x_train, y_train)
    y_pred = clf.predict(X_test)
    return pearsonr(y_test, y_pred)



kernels = [RBF()]


for kernel in kernels:
    latex_table.append([str(kernel)])
    for j in range(len(y_train)):
        pearson = get_pearsonvalue_GPR(X_train, y_train[j], X_test, y_test[j], kernel)
        print(pearson)
        latex_table[-1].append(str(pearson[0])[:6])


print(create_table(latex_table))





clf = LinearSVR(epsilon=0.8).fit(X_train, y_train[0])
features = findBestFeatures(15, clf.coef_)
imp = [i[1] for i in features]


mostImportantFeatures = []
for val in x:
    mostImportantFeatures.append([val[i] for i in imp])


latexTable = []
for n in range(90, 91, 10):
    features = findBestFeatures(n, clf.coef_)
    imp = [i[1] for i in features]
    mostImportantFeatures = []
    for val in x:
        mostImportantFeatures.append([val[i] for i in imp])
    latexTable.append([n] + list(getScores(mostImportantFeatures, y)))



latexTable.append(['all'] + list(getScores(x, y)))

print(create_table(latexTable))




