import pandas as pd
from sklearn.gaussian_process.kernels import DotProduct, WhiteKernel
from sklearn import svm
from sklearn.linear_model import Ridge
from sklearn.gaussian_process import GaussianProcessRegressor
from sklearn.feature_extraction.text import TfidfVectorizer
from scipy.stats import pearsonr

combined_df = pd.concat([essays_df, mypersonality_df], ignore_index=True)

extr = combined_df['sEXT'].values.tolist()
text = combined_df['TEXT'].values.tolist()
y = []
for i in range(len(extr)):
    y.append(float(extr[i]))




train = combined_df.head(int(combined_df.shape[0]*0.8))
test = combined_df.tail(int(combined_df.shape[0]*0.2))

y_train_extr = pd.to_numeric(train.sEXT)
y_test_extr = pd.to_numeric(test.sEXT)

y_train_agr = pd.to_numeric(train.sAGR)
y_test_agr = pd.to_numeric(test.sAGR)

y_train_cons = pd.to_numeric(train.sCON)
y_test_cons = pd.to_numeric(test.sCON)

y_train_emot = pd.to_numeric(train.sNEU)
y_test_emot = pd.to_numeric(test.sNEU)

y_train_open = pd.to_numeric(train.sOPN)
y_test_open = pd.to_numeric(test.sOPN)

text_train = train.TEXT
text_test = test.TEXT


y_train = [y_train_extr, y_train_agr, y_train_cons, y_train_emot, y_train_open]
y_test = [y_test_extr, y_test_agr, y_test_cons, y_test_emot, y_test_open]



uni_vectorizer = TfidfVectorizer(analyzer='char', ngram_range=(5, 10), stop_words='english', max_features=1000)
uni_x_train = uni_vectorizer.fit_transform(text_train)
uni_x_test = uni_vectorizer.transform(text_test)




latex_table = []

def create_table(matrix):
    table_string = ''
    for row in matrix:
        for element in row[:-1]:
            table_string += str(element) + ' & '
        table_string += str(row[-1]) + ' \\\\ \n'
    return table_string



def get_pearsonvalue_GPR(x_train, y_train, X_test, y_test):
    clf = GaussianProcessRegressor(kernel=DotProduct() + WhiteKernel())
    clf.fit(x_train, y_train.values)
    y_pred = clf.predict(X_test)
    return pearsonr(y_test.values, y_pred)



def get_pearsonvalue_SVR(x_train, y_train, X_test, y_test):
    print(len(y_train))
    print(len(y_test))
    clf = svm.SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2)
    clf.fit(x_train, y_train.values)
    y_pred = clf.predict(X_test)
    return pearsonr(y_test.values, y_pred)



for n in [1, 2]:
    latex_table.append([str(n)])
    uni_vectorizer = TfidfVectorizer(ngram_range=(n, n), stop_words='english', max_features=1000)
    uni_x_train = uni_vectorizer.fit_transform(text_train)
    uni_x_test = uni_vectorizer.transform(text_test)
    for j in range(len(y_train)):
        pearson = get_pearsonvalue_SVR(uni_x_train.toarray(), y_train[j], uni_x_test.toarray(), y_test[j])
        latex_table[-1].append(str(pearson[0])[:6])


print(create_table(latex_table))



"""
Ridge regression
"""
#EXT
clf = Ridge(alpha=1500.0)
clf.fit(uni_x_train, y_train_extr)
clf.score(uni_x_test, y_test_extr)


"""
SVR
"""
results = ""

# extr
clf = svm.SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2).fit(uni_x_train, y_train_extr)
y_pred = clf.predict(uni_x_test)
pearson = pearsonr(y_test_extr.values, y_pred)
results += (" Extr: " + str(pearson))

# agr
clf = svm.SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2).fit(uni_x_train, y_train_agr)
y_pred = clf.predict(uni_x_test)
pearson = pearsonr(y_test_agr.values, y_pred)
results += (" Agr: " + str(pearson))

# cons
clf = svm.SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2).fit(uni_x_train, y_train_cons)
y_pred = clf.predict(uni_x_test)
pearson = pearsonr(y_test_cons.values, y_pred)
results += (" Cons: " + str(pearson))

# emot
clf = svm.SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2).fit(uni_x_train, y_train_emot)
y_pred = clf.predict(uni_x_test)
pearson = pearsonr(y_test_emot.values, y_pred)
results += (" Emot: " + str(pearson))
# open
clf = svm.SVR(kernel='linear', gamma='scale', C=15, epsilon=0.2).fit(uni_x_train, y_train_open)
y_pred = clf.predict(uni_x_test)
pearson = pearsonr(y_test_open.values, y_pred)
results += (" Open: " + str(pearson))

results



"""
GP
"""

kernel = DotProduct() + WhiteKernel()
#kernel = RBF(length_scale=1.0) + WhiteKernel()

results = ""

# extr
gpr = GaussianProcessRegressor(kernel=kernel).fit(uni_x_train.toarray(), y_train_extr.values)
y_pred = gpr.predict(uni_x_test.toarray())
pearson = pearsonr(y_test_extr.values, y_pred)
results += ("Extr: " + str(pearson))

# agr
gpr = GaussianProcessRegressor(kernel=kernel).fit(uni_x_train.toarray(), y_train_agr.values)
y_pred = gpr.predict(uni_x_test.toarray())
pearson = pearsonr(y_test_agr.values, y_pred)
results += ("Agr: " + str(pearson))

# cons
gpr = GaussianProcessRegressor(kernel=kernel).fit(uni_x_train.toarray(), y_train_cons.values)
y_pred = gpr.predict(uni_x_test.toarray())
pearson = pearsonr(y_test_cons.values, y_pred)
results += ("Cons: " + str(pearson))

# emot
gpr = GaussianProcessRegressor(kernel=kernel).fit(uni_x_train.toarray(), y_train_emot.values)
y_pred = gpr.predict(uni_x_test.toarray())
pearson = pearsonr(y_test_emot.values, y_pred)
results += ("Emot: " + str(pearson))
# open
gpr = GaussianProcessRegressor(kernel=kernel).fit(uni_x_train.toarray(), y_train_open.values)
y_pred = gpr.predict(uni_x_test.toarray())
pearson = pearsonr(y_test_open.values, y_pred)
results += ("Open: " + str(pearson))

results
