import re
import numpy as np
import nltk
import pandas as pd
from langdetect import detect
from nltk.corpus import stopwords
nltk.download('stopwords')

stop_words = set(stopwords.words('english'))

def preprocess(text):
    # lowercase
    text = ''.join(text).lower()
    # mentions & URLs
    text = ' MENTION '.join(re.split(r'\*propname\*', text))
    text = ' URL '.join(re.split(r'http:////[a-z0-9/._-]*', text))
    # remove symbols
    text = ' '.join(re.split(r'\W+', text))
    #text = ' '.join([x for x in text.split() if x not in stop_words])
    return text



mypersonality_raw = pd.read_csv('mypersonality.csv')

# remove unneeded fields
relevantFields = mypersonality_raw[['#AUTHID', 'STATUS', 'sEXT', 'sNEU', 'sAGR', 'sCON', 'sOPN']]

# combine the users
mypersonality_combined_tweets = relevantFields.groupby(['#AUTHID', 'sEXT', 'sNEU', 'sAGR', 'sCON', 'sOPN'])['STATUS'].apply(lambda x: ' '.join(x.astype(str))).reset_index()


for index, row in mypersonality_combined_tweets.iterrows():
    row['STATUS'] = preprocess(row['STATUS'])
    mypersonality_combined_tweets.loc[index, 'STATUS'] = row['STATUS']
    # checking for english
    # TODO: consider doing this on a tweet-level and remove only if less than 20% are english
    if detect(row["STATUS"]) != 'en':
        print(row["STATUS"])
        mypersonality_combined_tweets.drop(mypersonality_combined_tweets.index[index])


mypersonality_df = mypersonality_combined_tweets[['sEXT', 'sNEU', 'sAGR', 'sCON', 'sOPN', 'STATUS']]
mypersonality_df.columns = ['sEXT', 'sNEU', 'sAGR', 'sCON', 'sOPN', 'TEXT']




### Calculating the mean value for each label of each trait:
mypersonality_raw = pd.read_csv('mypersonality.csv')

ext_y = []
ext_n = []
agr_y = []
agr_n = []
neu_y = []
neu_n = []
con_y = []
con_n = []
opn_y = []
opn_n = []


for index, row in mypersonality_raw.iterrows():
    if row["cEXT"] == 'y':
        ext_y.append(row["sEXT"])
    else:
        ext_n.append(row["sEXT"])
    if row["cAGR"] == 'y':
        agr_y.append(row["sAGR"])
    else:
        agr_n.append(row["sAGR"])
    if row["cNEU"] == 'y':
        neu_y.append(row["sNEU"])
    else:
        neu_n.append(row["sNEU"])
    if row["cCON"] == 'y':
        con_y.append(row["sCON"])
    else:
        con_n.append(row["sCON"])
    if row["cOPN"] == 'y':
        opn_y.append(row["sOPN"])
    else:
        opn_n.append(row["sOPN"])


avg_ext_y = np.mean(ext_y)
avg_ext_n = np.mean(ext_n)
avg_agr_y = np.mean(agr_y)
avg_agr_n = np.mean(agr_n)
avg_neu_y = np.mean(neu_y)
avg_neu_n = np.mean(neu_n)
avg_con_y = np.mean(con_y)
avg_con_n = np.mean(con_n)
avg_opn_y = np.mean(opn_y)
avg_opn_n = np.mean(opn_n)
