# -*- coding: utf-8 -*-
import gensim
import glob
import re
import numpy as np
import pandas as pd
from gensim import models
from gensim.test.utils import datapath
from sklearn.svm import SVR
from pprint import pprint
import pyLDAvis
import pyLDAvis.gensim  # don't skip this
import matplotlib.pyplot as plt
#matplotlib inline


def preprocess(text):
    text = ''.join(text).lower()
    text = ' '.join(re.split(r'\W+', text))
    text = text.replace(' um ', ' ')
    return text


personality_scores_df = pd.read_csv('youtube-personality/YouTube-Personality-Personality_impression_scores.csv', sep=' ')

transcripts = []
files = glob.glob('youtube-personality/transcripts/*')
for file in files:
    vlog_id = file.split('/')[2]
    f = open(file, 'r')
    txt = f.readlines()
    f.close()
    text = preprocess(txt)
    transcripts.append([vlog_id[:-4], text])


transcripts_df = pd.DataFrame(np.array(transcripts), columns = ['vlogId', 'text'])
combined_df = personality_scores_df.set_index('vlogId').join(transcripts_df.set_index('vlogId'))


train = combined_df.head(int(combined_df.shape[0]*0.8))
test = combined_df.tail(int(combined_df.shape[0]*0.2))


x_train = []
for text in combined_df['text'].values.tolist():
    x_train.append(gensim.utils.simple_preprocess(text))


dictionary = gensim.corpora.Dictionary(x_train)

# Filters out words that appear in less than 15 documents and more than 50% of all documents
dictionary.filter_extremes(no_below=5, no_above=0.5, keep_n=10000)

# Counts how many times the word is in the document
bow_corpus = [dictionary.doc2bow(doc) for doc in x_train]


train = bow_corpus[:int(len(bow_corpus)*0.8)]
test = bow_corpus[int(len(bow_corpus)*0.8):]

# TF-IDF
tfidf = models.TfidfModel(train)
corpus_tfidf = tfidf[train]

for doc in corpus_tfidf:
    pprint(doc)
    break

# LDA using BoW
lda_model = gensim.models.LdaMulticore(train, num_topics=8, id2word=dictionary, passes=2, workers=2)
for idx, topic in lda_model.print_topics(-1):
    print('Topic: {} \nWords: {}'.format(idx, topic))


# LDA using TF-IDF
lda_model_tfidf = gensim.models.LdaMulticore(corpus_tfidf, num_topics=10, id2word=dictionary, passes=2, workers=4)
for idx, topic in lda_model_tfidf.print_topics(-1):
    print('Topic: {} Word: {}'.format(idx, topic))


# Saving the model to a file that can be loaded at a later time
temp_file = datapath("bow_model")
lda_model.save(temp_file)

# a measure of how good the model is. lower the better.
lda_model.log_perplexity(train)

# Compute Coherence Score another perfomrnace model, higher is better
coherence_model_lda = models.CoherenceModel(model=lda_model, texts=x_train, dictionary=dictionary, coherence='c_v')
coherence_lda = coherence_model_lda.get_coherence()
print('\nCoherence Score: ', coherence_lda)

# Visualize the topics
vis = pyLDAvis.gensim.prepare(lda_model, train, dictionary)
pyLDAvis.save_html(vis, 'LDA_Visualization3.html')

# Running the LDA on one instance (just an example)
#for index, score in sorted(lda_model[bow_corpus[2]], key=lambda tup: -1*tup[1]):
#    print("\nScore: {}\t \nTopic: {}".format(score, lda_model.print_topic(index, 10)))
"""
# creating a feature set from the data
labels = {'unrelated': 0, 'pro_ed': 1, 'pro_recovery': 0}
featureset = []
for i in range(len(bow_corpus)):
    label = labels[users[i][-1]]
    featureset.append(lda_model[bow_corpus[i]] + [label])

"""

# Determining the optimal number of topics.
"""
Compute c_v coherence for various number of topics
Parameters:
----------
dictionary : Gensim dictionary
corpus : Gensim corpus
texts : List of input texts
limit : Max num of topics

Returns:
-------
model_list : List of LDA topic models
coherence_values : Coherence values corresponding to the LDA model with respective number of topics
"""
def compute_coherence_values(dictionary, corpus, texts, limit, start=2, step=3):
    coherence_values = []
    model_list = []
    for num_topics in range(start, limit, step):
        print(num_topics)
        model = gensim.models.LdaMulticore(corpus, num_topics=num_topics, id2word=dictionary, passes=2, workers=2)
        model_list.append(model)
        print("Done making the model")
        coherencemodel = models.CoherenceModel(model=model, texts=texts, dictionary=dictionary, coherence='c_v')
        coherence_values.append(coherencemodel.get_coherence())
    return model_list, coherence_values


model_list, coherence_values = compute_coherence_values(dictionary=dictionary, corpus=train, texts=x_train, start=5, limit=25, step=3)

# Visualize the model
limit = 25
start = 5
step = 3
x = range(start, limit, step)
plt.plot(x, coherence_values)
plt.xlabel("Num Topics")
plt.ylabel("Coherence score")
plt.legend(("coherence_values"), loc='best')
plt.show()


"""
SVR (SVM regression)
"""

extr = combined_df['Extr'].values.tolist()
X = []
y = []
for i in range(len(bow_corpus)):
    X.append(lda_model[bow_corpus[i]])# funker hvis man bare tar første element
    y.append(float(extr[i]))


X = np.array(X)
X = np.reshape(X, (404, 1))
y = np.array(y)
y = np.reshape(y, (404, 1))
clf = SVR(gamma='scale', C=1.0, epsilon=0.2)
clf.fit(X, y)

"""
# Test
n_samples, n_features = 404, 1
y = np.random.randn(n_samples)
X = np.random.randn(n_samples, n_features)
clf = SVR(gamma='scale', C=1.0, epsilon=0.2)
clf.fit(X, y)
"""

