import csv
import codecs
import re
import numpy as np
from langdetect import detect

"""

For each tweet:
v 1. unicode
v- 3. print all remaining emoji-matches - see what is left
v 4. Remove emojis with numbers removed + /
v 5. change ' amp ' to and
v 2. Check language
 7. combine tweets  / user
 8. remove less than 20
 9. save all tweets from users not in delete list

delete all x-s standing alone?
'rt MENTION minxe x bxb xe x xb xe x x xe x x bxe x xa xe x x dxe x x cxe xbbxa xe xb x axe x xaexe x xb xe x xa xe x xafxe x xbfxe x x fxe x x fxe x xaaxe x x fxe x xa xe x x xe xbbx axe x x xe x x axe x x xe xa xb xe x x xe x xa xe x x bxe x x xe xa xbaxe xaex fxe x xabxe x x xe x x cxe xbbxa xe xb x axe x xafxe x x xe x x bxe x xa xe x x dxe x x xe x x bxe x x xe x x xe x x xe x x xe x x xe x xabxe x x xe x xaexe xbdx xe x x dxe x xaexe x xadxe x xbcxe x x xe x xafxe x xa xe x x xe x xa xe x xa xe xa xa xe x xa xe x xa xe x x xe x xa xe x x xe x x xe x x xe x xafxe x x axe xabx cxe x xa xe x x xe x fxbexe xaex fxe x x xe x xbfxe x x xe xbdx xe x x dxe xa x xe x xabxe xb x xe x x cxe x xaaxe x x xe x x xe x x  URL',


All emojis start with xf0

"""

TEXTINDEX = 5

# Removes all emojis
def clean_text(text):
    try:
        rgx = r"(x[a-f0-9]{2})"
        new_text = text
        new_text = re.sub(rgx, r'\\\1', new_text)
        backslashRemovedText = new_text.encode().decode('unicode-escape')
        final = backslashRemovedText.encode('latin-1').decode('utf-8')
        final_1 = final.replace('\x00', ' ')
        final_1 = final_1.replace('\x85', ' ')
        final_1 = final_1.replace('\x1d', ' ')
        final_1 = final_1.replace('\x1c', ' ')
        final_1 = final_1.replace('\x1e', ' ')
        if final != final_1: print(final + final_1)
        return final_1
    except Exception as e:
        return text


def removeRemainingHex(text):
    rgx = r"\sx[a-f]{0,1}\s"
    new_text = re.sub(rgx, ' ', text)
    new_text = re.sub(rgx, ' ', new_text)
    rgx2 = r"\\x[a-f]{1,2}"
    new_text = re.sub(rgx2, ' ', new_text)
    return new_text


def replaceAMP(text):
    rgx = r"\samp\s"
    new_text = re.sub(rgx, ' and ', text)
    return new_text


def mergeSMT(text):
    new_text = text.replace(' s ', 's ')
    new_text = new_text.replace(' t ', 't ')
    new_text = new_text.replace(' m ', 'm ')
    return new_text


# Not used but will be used in tests
def removeNumbers(text):
    return re.sub(r'\d+', '', text)


# NB! Remember to check no runtime errors
# Remove numbers?
def preprocess(tweet):
    text = clean_text(tweet)
    text = removeRemainingHex(text)
    text = replaceAMP(text)
    text = mergeSMT(text)
    text = removeNumbers(text)
    return text


def languageDetection(tweets):
    englishTweets = []
    for i in range(len(tweets)):
        if len(tweets[i][TEXTINDEX].strip()) < 1:
            pass
        try:
            if detect(tweets[i][TEXTINDEX]) == 'en':
                englishTweets.append(tweets[i])
        except Exception as e:
            print(e)
            print('Tweet: ' + tweets[i][TEXTINDEX])
    return englishTweets


def deleteLessThanXTweets(tweets, minimumTweets):
    users = {}
    for row in tweets:
        username = row[1]
        if username in users:
            users[username][TEXTINDEX].append(row[TEXTINDEX])
        else:
            users[username] = row[0:TEXTINDEX] + [[row[TEXTINDEX]], row[6]]
    keepTweets = []
    print(len(users.keys()))
    for user in users.keys():
        if len(users[user][TEXTINDEX]) >= minimumTweets:
            for tweet in users[user][TEXTINDEX]:
                keepTweets.append(users[user][0:TEXTINDEX] + [tweet, users[user][6]])
    return keepTweets



# Testing

def loadDataset(filename):
    dataset = []
    #with open('data/' + filename + '.csv') as csv_file:
    csv_reader = csv.reader(codecs.open('data/' + filename + '.csv', 'rU', 'utf-8'), delimiter=',')
    for row in csv_reader:
        dataset.append(row)
    return dataset


def saveDataset(filename, dataset, mode='w'):
    with open('data/' + filename + '.csv', mode=mode, encoding='utf-8') as csv_file:
        csv_writer = csv.writer(csv_file, delimiter=',')
        for row in dataset:
            csv_writer.writerow(row)


def testLanguages(dataset):
    languages = {'en': 0}
    for i in range(len(dataset)):
        if len(dataset[i][TEXTINDEX].strip()) < 1:
            pass
        try:
            lang = detect(dataset[i][TEXTINDEX])
            if lang in languages:
                languages[lang] += 1
            else:
                print(lang)
                print(dataset[i][TEXTINDEX])
                languages[lang] = 0
        except Exception as e:
            pass
            #print(e)
            #print('Tweet: ' + dataset[i][TEXTINDEX])
    return languages



data = loadDataset('total_final')

processedTweets = []
for i in range(len(data)):
    row = data[i]
    if i % 100000 == 0: print(i)
    if row[9] == 'class':
        continue
    # displayname, username(id), date + time of tweet, bio, location, text, label
    processedTweets.append([row[5], row[1], row[4], row[3], row[6], clean_text(row[7]), row[9]])



for i in range(len(processedTweets)):
    if processedTweets[i][-1] == "unrelater":
        processedTweets[i][-1] = "unrelated"
        print(processedTweets[i][0])



languages = testLanguages(processedTweets)

"""
data = loadDataset('reduced')
processedTweets = []
for i in range(len(data)):
    row = data[i]
    if i % 1000 == 0: print(i)
    if row[9] == 'class':
        continue
    # displayname, username(id), date + time of tweet, bio, location, text, label
    processedTweets.append([row[5], row[1], row[4], row[3], row[6], preprocess(row[7]), row[9]])



englishTweets = languageDetection(processedTweets[:30000] + processedTweets[-30000:])


keepTweets = deleteLessThanXTweets(englishTweets, 20)


saveDataset('moreThan20', keepTweets)


"""
# Processing applied to actual dataset
data = loadDataset('dec_hex_smt_amp')
processedTweets = []
for i in range(len(data)):
    row = data[i]
    if i % 100000 == 0: print(i)
    if row[-1] == 'class':
        continue
    # displayname, username(id), date + time of tweet, bio, location, text, label
    processedTweets.append(row[:5] + [removeNumbers(row[5]), row[6]])


del data
saveDataset('dec_hex_smt_amp_num', processedTweets)



data = loadDataset('final')
keepTweets = deleteLessThanXTweets(data, 20)

saveDataset('moreThan20', keepTweets)

data = loadDataset('moreThan20')
#del keepTweets
processedTweets = []
for i in range(len(data)):
    row = data[i]
    if i % 100000 == 0: print(i)
    if row[-1] == 'class':
        continue
    # displayname, username(id), date + time of tweet, bio, location, text, label
    processedTweets.append([preprocess(row[0])] + row[1:3] + [preprocess(row[3]), preprocess(row[4])] + row[5:])


del data
saveDataset('final', processedTweets)

"""
startingPoint = loadProgress()

#saveDataset('englishTweets', [])
for i in range(startingPoint, len(data), 30000):
    print(i)
    englishTweets = []
    englishTweets = languageDetection(unprocessedTweets[i:i+30000])
    saveDataset('englishTweets', englishTweets, 'a')
    saveProgress(i+30000)



englishTweets = []
englishTweets = languageDetection(unprocessedTweets[i:])
saveDataset('englishTweets', englishTweets, 'a')
saveProgress(len(data))



def loadProgress():
    with open('preprocessingProgress.txt', 'r') as f:
        progress = f.read()
    f.close()
    return int(progress.strip())



def saveProgress(progress):
    with open('preprocessingProgress.txt', 'w') as f:
        f.write(str(progress))
    f.close()
    return True




numericTweets = []
for i in range(len(data)):
    if re.match('^[0-9][0-9 ]*$', data[i][7]):
        #print(data[i][7])
        numericTweets.append(data[i][7])

len(numericTweets)



saveDataset('englishTweets', numericTweets, 'a')

count = {'pro_ed': 0, 'unrelated': 1, 'pro_recovery': 0, 'unrelater': 0}


for tweet in numericTweets:
    count[tweet[-1]] += 1




englishTweets = loadDataset('englishTweets')
"""
"""

 anorexia
 skinny4xmas
 xff


'xedx95xa0xeaxbaxbc xebxa7x8execx95x84 xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa02ne1tv xebxb6x80xedx84xb0xebxb3xb4xecx9ex90', 'MENTION xebxa8xb8xebxa6xbfxecx86x8dxecx97x90 xeaxb0x80xecx8axb4xecx86x8dxecx97x90 xecx98xa4xebx9ex98xebx8fx84xebxa1x9d xebx82xa8xebx8ax94 xecx9dx8cxecx95x85xebx82x98xebx8fx84 xebxaaxa8xebxa5xb4xebx8ax94 xecx82xacxecx9dxb4xecx97x90 xecx9ex90xebxa6xacxecx9exa1xecx9dx80 xebx93xaf xebx93x80xeaxb7xbcxeaxb1xb0xebxa6xacxebx8ax94 xecx9dxb4xebxafxb8xecxa7x80', 'MENTION xebx84x88xebx8fx84 xecxa2x80xecx97xb0xecx95xa0xecxa2x80', 'MENTION xedx8ex8cxedx82xa8 xebx8fx99xecx83x9dxecx9dx80 xeaxb7xb8xebx9fxbc xecx95xa0xedx98xb8xebxb0x95xecx9ex84xeaxb0x80', 'MENTION xedx81xb0 xedx9ex98xecx9dxb4 xebx90x9cxebx8bxa4xebx8axa5 xe3x85x8exe3x85x8exe3x85x8exe3x85x8exe3x85x8exe3x85x8e', 'xecx98xa4xebx8ax98xecx9dx80 xeaxb0x9cxeaxb5x90xeaxb8xb0xebx85x90xecx9dxbcxeaxbfx80xeaxb0x99xeaxb5xb0', 'MENTION xebx82xadxecxb6xa9xecx9dxb4 xecx99xb8xeaxb5xadxecxb9x9cxeaxb5xacxebx93xa4xebx8fx84xecx9ex88xecx97x88xebx8bx88', 'MENTION xecx82xacxebx9ex8cxebx8bxa4xecx9axb4 xebx8bxb5xecx9exa5xecxa2x80 xebxb3xb4xebx82xb4xecxa3xbcxecx8bx9cxeaxb8xb8', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxebx82x9c xecx95x8cxebxb0x94xecx97xac xeaxb7xb8xebxa0x87xeaxb5xb0 xebx82xa0xecx94xa8 xecxa2x8bxecxa7x80xe3x85x8bxe3x85x8bxe3x85x8b', 'fuck fuck alcoholfuckalcohol is deadly dangerous no one should drink it', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxedx9dx90xebxafxb8xedx9dx90xebxafxb8 xebxb9xa8xebxa6xacxedx96x89xedx96x89xedx96x89xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxebx82x98xebx9ex91xebx86x80xecx9ex90 xe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION xecxa0x80xebx85x81xecx95xa0 xebxadx90xedx95x98xecx85x8d', 'happy birthday xecx96xb8xebx8bx88xebx8bx98', 'MENTION xebx84x8c xeaxb1x8d xecx8axa4xedx88xacxedx94xbcxebx91x90', 'MENTION im a huge fan of ursluv from seoul to fiercelandd', 'xebxaaxa9xebx8fx99xecx9dx80 xecxb2x98xecx9dx8cxecx9cxbcxebxa1x9c xecx98xa4xebx8ax94xebx93xaf xebxaaxa9xebx8fx99xeaxb4x80xeaxb4x91xecxa4x91xecx84x9cxecx9axb8xecxb4x8cxebx86x88', 'xecx98xa4xebx8ax98xecx9dx80 xedx95x98xebxa3xa8xecxa2x85xecx9dxbc xecx9exa0xebxa7x8c xecx9ex90xeaxb3xa0 xecx8bxb6xecx9dx80 xebx82xa0xecx9dxb4xebx8bxa4xedx95x98xecxa7x80xebxafxbc xeaxb7xb8xebx9fxb0xeaxb1xb4 xebxacxb4xecxb1x85xecx9ex84xedx95xa0xebxbfx90', 'MENTION xecx98xa4xebxb9xa0xebx8fx84 xecx9dxb4xecx81x9cxecx97xacxecx9ex90 xecxa2x8bxecx95x84xedx95xb4xecx9ax94xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx95x84 xebx82xa8xecx9ex90xebx93xa4xebx8bxa4 xecx9dxb4xebxbfx90xecx97xacxecx9ex90xebxa7x8c xecxb0xbexecx95x84 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION xe3x85x89xe3x85x89xedx94xbcxeaxb3xa4xedx95x98xeaxb5xacxebxa7x8c', ' MENTION xedx81xacxebx9ex98xecxbbxa4 11xecx9bx94xedx98xb8xeaxb0x80 xebx93x9cxebx94x94xecx96xb4 xebx82x98xecx99x94xecx8bxacxebx8bxa4 xecx95x84xebxa7x88 xebx82xb4xecx9dxbcxebxb6x80xedx84xb0 xecx84x9cxecxa0x90xecx97x90 xebx93xa4xecx96xb4xeaxb0x88xebx93x9d xe3x85xa1 xecx9dxb4xebxb2x88xebx8bxacxecx9dx80 xecx8axa4xedx8ex98xecx85x9c xecx97x90xebx94x94xecx85x98xecx9cxbcxebxa1x9c xedx99x95 xebxb0x94xebx80x8cxecx97x88xecx8axb5xebx8bx88xebx8bxa4 xebxa7x8execx9dx80 xeaxb4x80xecx8bxacxeaxb3xbc rtxebxb6x80xedx83x81xebx93x9cxebxa6xbdxebx8bx88xebx8bxa4 xedx9dx90xedx97x88xedx97x9b ', 'MENTION xebx82x98 xebx94x94xecx9ex90xecx9dxb8xedx8cx80 xedx95xa9xebxa5x98 xeaxb2xb0xecxa0x95 xecxa3xbdxecx96xb4xebx82x98xebxb3xb4xecx9ex90', 'xe3x85x8exe3x85x8e URL', 'popopopopocker facexecx96x8d', 'MENTION shutupboy', 'MENTION xecx95x84xebx8bx88xecx97x90xecx97xac xe3x85x8bxe3x85x8bxe3x85x8bxecxa2x8bxecx9dx80 xeaxb2xbdxedx97x98xecx9dxb4xecx97x88xecx96xb4xecx9ax94xe3x85x8exe3x85x8exe3x85x8exe3x85x8exebx8dx94 xecx97xb4xecx8bxacxedx9ex88 xedx95xb4xecx95xbcxecxa0xb8', 'xebxaax85xebx8fx99xecx9dx80 xecx82xacxebx9ex8cxecx9dx84 xecxa7x80xecxb9x98xeaxb2x8cxedx95xb4', 'MENTION xecx95x97xecx8bxb8xebxa7xa4xecx9axb0xeaxb0x90xecx82xacxedx95xa9xebx8bx88xebx8bxa4 xeaxb8xb0xecx81x98xebx84xa4xecx97xac xebx84x99xecxa3xbdxebx84x99xecxa3xbd', 'MENTION xecx9dx8c xebx94x94xecxa0x9cxecx9dxb4xeaxb7xb8xebxa3xb9xe3x85x8bxe3x85x8bxedx95x9cxebxb2x88 xebx93xa4xecx96xb4xebxb3xb4xecx9ax94 idiotape xe3x85x8bxe3x85x8bxeaxb7xb8xebxa6xacxeaxb3xa0 xecxa0x80 xecx9ex8axecxa7x80xecx95x8axecx95x98xecx96xb4xecx9ax94 xe3x85x8exe3x85x8exedx8fxacxeaxb8xb0xedx95x98xecxa7x80xebxa7x88xecx84xb8xecx9ax94 xe3x85x8b', 'MENTION xecx8bxa4xebxa0xa5xebxb0x9cxedx9cx98 xedx95xb4xecxa3xbcxecx85xa8xecxa3xa0xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION xecx9dx91xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx99x9cxecx96x91', 'MENTION xecxa6x90xeaxb8xb0xebx8bxa4 xebxa9x94xebx9fxacxebx94x94xecx8axa4 xecx95x84xecxa7x81xebx8fx84 xecx9ex88xebx83x90xebx82x9c xeaxb7xb8xecx82xacxebx9ex80 xecx8bxabxecx96xb4', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxecx99x9cxecx97xacxecx9dxb4xeaxb5xb4xebxa5xb4xecx8axa4xe3x85x8exe3x85x8exe3x85x8execxb5x9cxeaxb7xbcxecx97x90 xeaxb0x88xecx95x84xedx83x94xebx8ax94xebx8dxb0xecxa0x9c xebxb8x94xebxa1x9cxeaxb7xb8xecx97x90 xebx93xa4xebxa0xa4xecxa3xbcxecx85xa8xecx97x88xecx96xb4xecx9ax94 xe3x85x8exe3x85x8exe3x85x8exe3x85x8e', 'xecx86x90xebx8bx98xebx93xa4xecx9dxb4 xebxa8xb8xebxa6xac xeaxb7x80xecx97xbdxebx8cx84xebx8bxa4 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8exe3x85x8exe3x85x8e', 'MENTION xeaxb5xbfxecx9exa1', 'hood  hood hoodie', 'MENTION xecx9dxb4xeaxb1xb0 xebx91x90xebxaax85xecx9dx98 xeaxb8xb0xebx8cx80xecx97x90 xecxa0x80xebxb2x84xebxa6xacxebxa9xb4 xecx95x88xebx90x98xeaxb2xa0xebx84xbcxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'xecx95x88xeaxb3xbcxecx97x90 xecx82xacxebx9ex8c xecx99xa4xecxbax90 xebxa7x8execx95x84', 'xebx82xadxecxb6xa9xecx9dxb4xeaxb0x80 xedx84xb0xedx82xa4xecx97x90xecx84x9c xebx8fx8cxecx95x84xecx99x93xebx8bxa4 xe3x85x8bxecxbcx80xebxb0xa5xebx83x84xecx83x88 xedx92x8dxeaxb8xb0xeaxb2xa0xeaxb5xb0 xecxa7x9cxecx8bx9d', 'xecx9bx83xeaxb8xb0xecxa7x80xebxa7x88xe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION xecx9dx8c xebx82x9c xebxafxb8xebx94x94xecx96xb4xecx8axa4xedx84xb0xebx94x94xeaxb0x80 xecx95xbcxecx99xb8xecx88x98xecx97x85xecx9dxb4xecx95xbc xecx9dx84xecxa7x80xebxa1x9cxecx97x90xecx84xb1 xe3x85x8exe3x85x8exe3x85x8exeaxb7xb8xeaxb1xb0 xebx81x9dxebx82x98xeaxb5xac xecx95xa0xebx93xa4xecx9dxb4xebx9ex91 xebx8bxa4xeaxb0x99xecx9dxb4 xeaxb0x88xebx93xaf', 'rt MENTION kt xedx99x8dxebxb3xb4xeaxb4x80xeaxb3x84xecx9ex90xeaxb0x80 xecx9dxb4xecxa0x84xecx97x90  xecx9dxb8xeaxb3xb5xecx9cx84xecx84xb1 xeaxb4x80xebxa0xa8 xebxacxbcxecx96xb4xebx8dx94xebx8bx88 xeaxb7xb8xecx83x88 xeaxb7xb8xeaxb1xb8 xecx83x81xedx92x88xecx9cxbcxebxa1x9c xeaxb1xb8xecx97x88xebx8bxa4 xebxa8xb8xebx83x90 xebx8fx84xebx8cx80xecxb2xb4', 'MENTION xebx84xa4xecx97xa5 xe3x85x8b xecxb0xb8xedx95x98xeaxb3xa0 xecx84xb1xeaxb2xa9xeaxb4x9cxecxb0xaexeaxb3xa0 xecx86x8d xeaxbdx89xecxb0xac xebx87xa8xecx9ex90xebxa1xb7xe3x85x8exe3x85x8execxb0xbexecx95x84xebxb3xbcxeaxbbx98xecx9ax94', 'xecx95x84 xeaxb7xb8xebxa7x8cxebx91xacxecx95xbcxecxa7x80', 'MENTION xecx98xa4xecxbcx80xecx9dxb4 xe3x85x8bxebx8bxb4xebxb2x88xecx97x90 xecxbbxa4xedx94xbc xebx8cx80xecxa0x91 xedx95xb4xeaxb7xb8xebxa6xb4xeaxbbx98xecx9ax94 xe3x85x8exe3x85x8exe3x85x8e', 'MENTION xecx95x8cxebxb0x94xedx95x98xebx8ax94xebx8dxb0 xecx82xacxecx9exa5xebx8bx98xecx9dxb4 xecx9dxb4xeaxb2x83xecxa3xbcxecx8bx9cxebx82xb4 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx82xb4xecxb0x8cxeaxb2xa0xecx96xb4 xe3x85xa0', 'xecxa0x84xedx98x80 xebxaaxa8xebxa5xb4xeaxb2xa0xecx9dx8c', 'xecxa0xa0xecx9exa5 xebx82xb4xeaxb0x80 xecx9dxb4xebx94x94xecx98xa4xedx85x8cxecx9ex8execx9dx84 xebx86x93xecxb3xa4xebx8bxa4xebx8bx88 xebxadx90 xecx96xb4xecxa9x94xecx88x98 xecx97x86xecx97x88xecxa7x80xebx82xb4xebx85x84xecx9cxbcxebxa3xa8xeaxb8xb0xecx95xbdxedx95x98xebxa9xb0', 'MENTION xecx98xa4xebxb9xa0 xedx98xb9xecx8bx9c xedx82xa4 xecxa0x9cxedx95x9c xecx9ex88xecx96xb4xecx9ax94xe3x85x8exe3x85x8e', 'MENTION xebx8bxb9xecx97xb0xedx95x98xecxa7x80 xebx82x9c xedx88xacxecx97x90xebx8bx88xecx9bx90 xebxb9xa0xecx97xac xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'xebx82xb4xeaxb0x80 xebxbdx91xecx9dx80 xecxb2xab xecx97x90xecx8axa4xedx94x84xebxa0x88xecx86x8c xedx9dxa0', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx95x84 xecx99x9c xebx82x98xebx8fx84 xebx82xb4xeaxb0x80 send xebx88x84xebxa5xb4xebx8ax94 xecx88x9cxeaxb0x84xebxb6x80xedx84xb0 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxebxb6x88xeaxb8xb8xedx95x98xecxa7x80 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION hey smart phones so convenientlol', 'MENTION xecx98xa4 xeaxb7xb8xebx9ex98xecx84x9c xecx98x80xeaxb5xacxebx82x98trick xeaxb3xbc treat xecx9dx84 xebxb0x9bxecx95x98xeaxb5xb0xecx9ax94 xecxa0x84 xecx98xa4xebx8ax98 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'xecxb6x95xecxa0x9cxebx9ex98 xe3x85x86xebx94x94xecx9ex90xecx9dxb4xebx84x88xebx9ex80 xebxacxb4xecx97x87xecx9dxb8xeaxb0x80 xebx82xb4xeaxb0x80 xecx95x8cxeaxb2x8cxebxadx90xecx95xbcxebx9dxbcxebx8ax94 xecx8bxacxecxa0x95', 'MENTION xecx99x9c xecxa0x84xedx99x94 xecx95x8axebxb0x9bxecxa7x80xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxeaxb1xb1xecxa0x95xebx90x98xebx84xa4 xebxacxb8xecx9ex90xebx8fx84 xebx8bxb5xecx97x86xeaxb3xa0 xe3x85x8b', 'MENTION xecx9ex98 xecxa7x80xebx82xb4xecx8bx9cxecxa3xa0xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8exe3x85x8exe3x85x8exe3x85x8e', 'MENTION xedx88xacxecx9cx97 xebx8dx95xedx9bx84', 'MENTION xebxb9x84xebxa5xbc xebx9axabxeaxb3xa0 xecx88x98xecx97x85xebx8fx84xecxa4x91xecx97x90xe3x85x9cxebxa7x88xecx85xa8xecx96xb4 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxeaxb0x90xeaxb8xb0xecxa1xb0xecx8bxacxedx95x98xecx8bx9cxecx98xa4', 'xebx82xb4 xecxa3xbcxebxa8xb8xebx8bx88xebx8ax94 xebx91x90xebx91x91xedx95x98xebx8bxa4', '2ne1tv xedx95x98xebx8ax94xebx82xa0 xebxa3xb0xebxa3xa8xebx9ex84xebx9dxbc xecxa0x88xecx8dxa8 xecx9dxbcxecxa3xbcxecx9dxbcxecx9dxb4 xecxa7x80xebx82xacxeaxb5xb0 6xecx8bx9c', 'MENTION xecx98xa4xecxbax90xecx9dxb4', 'MENTION xecxa7x80xecxb9x98xebxa9xb4 xecx89xacxecx97x84xecx89xacxecx97x84 xedx95xb4xecx9ax94', 'xecxbbxa4xedx94xbcxecx83xb5xecx97x90 xedx9bx88xebx82xa8 xebx93xb1xecx9exa5 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx95x84 xedx9bx88xedx9bx88xedx95xb4 xecx84xb1xeaxb2xa9xebx8fx84 xecxa2x8bxecx95x84', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx98xa4xecx82x90 xecx95x88xebx85x95xedx95x98xecx84xb8xecx97xac xe3x85x8exe3x85x8exe3x85x8e xecx95x8cxebxb0x94 xedx95x98xebx8bxa4xeaxb0x80 xebxb9xa0 xeaxbexb8 xebx8bxb9xedx95xa8xebxadx90 xecx8bxa4xebxa7x9dxecx9dxb4xebx8bxa4 xebx9dxbcxebx8ax94 xebxa7x90xecx9dx84 xebxaax87xebxb2x88 xebx93xa4xecx97x87xebx88x88xecxa7x80', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx95x84 xecx99x84xecxa0x84 xedx9bx88xebx82xa8 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'xecx9ex98xecx83x9dxeaxb8xb0xebxa9xb4 xecx96xbcxeaxb5xb4xeaxb0x92 xedx95x98xeaxb3xa0 xebxaaxbbxecx83x9dxeaxb8xb0xebxa9xb4 xeaxbcxb4xeaxb0x91xedx95x9cxebx8cx84xebx8bxa4 xecx9ex84xebx82x98xebx9dxbcxe3x85x8e', 'MENTION xecx98xb7 xebx85xb8xecx83x81xecx9cxbcxebxa1x9c xecx96xb4xebx94x94xecx84x9c xedx8cx94xebxa9xb4 xecxa2x8bxecx9dx84xeaxb9x8cxecx9ax94xedx9dxa0', 'rt MENTION xeaxb8x80xeaxb0x9c xecx9dxb4xebxb2xa4xedx8axb8 xecx9dxb4xebxb2x88xecxa3xbc xedx86xa0xecx9ax94xecx9dxbc xecx97x90xecx8axa4xecxbdxb0xecx9dxb4xecx96xb4xeaxb0x80 xecx84xa0xecxa0x95xedx95x9c 2009xebx85x84 xebxb2xa0xecx8axa4xedx8axb8 xebx93x9cxebxa0x88xecx84x9c xebx8fx88 xebx94x94xecx95x84xebxb8x94xebxa1x9cxeaxb0x80 club answerxecx97x90 xecx98xb5xebx8bx88xebx8bxa4 xebx8bxa4xebx93xa4 xecx95x84xecx8bx9cxecxa3xa0 rt xebx82xa0xebxa0xa4xecxa3xbcxecx8bx9cxebx8ax94xebxb6x84 10xebxb6x84xeaxbbx98xebx8ax94 xedx8cx8cxedx8bxb0 xecxb4x88xebx8cx80 xecx8fx98xeaxb5xacxecx9ax94 xebx8bxb9xecxb2xa8xecx9ex90 xecxa4x91 xeaxb8x80xeaxb0x9c xedx8bxb0xecxbcx93 xecx98x88xebxa7xa4xecx9ex90xecx97x90xeaxb2x8cxebx8ax94  ', 'xebx82x9cxecxb2xadxecx9dxb4 xebxacxb8xecxa0x9cxecx9dxb8xebx93xaf xecx82xacxecx9exa5xebx8bx98 xecx9ex98 xecx95x8axebx93xa4xebxa0xa4xecx9ax94xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xedx95x98xecx95x84', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx95x84 xebx85xb8xebxa0xa5xecxa4x91xecx9ex84xe3x85x8bxe3x85x8bxe3x85x8b21xecx82xb4xecx96xb4xebx95x8cxecx9ax94xebx84x88xebxacxb4 xecx96xb4xebxa6xb0xeaxb0x80xecx9ax94', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx96xb4xecxa0x9c xecx86x8cxeaxb0x9cxedx8cx85 xedx96x88xecx9dx8c xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8cxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION xecx9ax94xecx9ax94 xecx9dxb4xecx8bxadxebxb6x84 xecxa7x80xeaxb0x81xebx82x98xebxa6x84 xebx84x88xeaxb5xacxebx9fxacxedx9ex88 xebx84x98xecx96xb4xeaxb0x80xecxa3xbcxecx8bxac xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx9ex98xedx95xb4xecx95xbcxebx94xa5', 'xebxb3xb4xecx9dxb4xedx94x84xebx9ex9cxebx93x9cxebxa3xa9 xecxa0x80xebxa6xacxeaxb0x80xebx9dxbcxedx95xa0xebxa7x8cxedx95xad xebx8cx80xebx94x94xebxa3xa9 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx95x84xebxb9xa0xecx98xb7xecx9ex85xeaxb3xa0 xebx8bxa4xebx8bx88xeaxb8xb0 xebxa7x9bxebx93xa4xebxa0xb8xebx8bxa4 xebxafxbfxecx9dx84xeaxb1xb4 xecx97xadxecx8bx9c xecx95x84xebxb9xa0xebxbfx90', 'MENTION somewhere between the internet lines lol we should meet somehow', 'xeaxb3xbcxecxa0x9c xebxa7x88xeaxb0x90 12xecx8bx9cxeaxb0x84xecxa0x84xecxa3xbdxecx9dx8cxecx9dx98 xebxa0x88xecx9dxb4xecx8axa4xebxa5xbc xecx8bx9cxecx9ex91xedx95xb4xebxb3xb4xecx9ex90xedx95x98xecx95x84 xeaxb8xb0xecx9axb4 xecx97x86xecx96xb4', 'xecx9exa1xecxa7x80xeaxb0x80 xecx82xacxeaxb3xa0 xecx8bxb6xebx84xa4', ' MENTION xecx98xa4xebx8ax98 xecx9cxa0xedx9dxacxecx97xb4xecx9dx98 xecx8axa4xecxbcx80xecxb9x98xebxb6x81  xecx8ax88xedx94x84xebxa6xbcxedx8cx80 xebx82x98xecx98xb5xebx8bx88xebx8bxa4 xebxaaxa8xebx91x90 xebxb3xb8xebxb0xa9xecx82xacxecx88x98  u here ', 'MENTION xeaxb5xacxebx9dxbcxeaxb9x8cxecxa7x80xebxa7x9b', 'MENTION xeaxb3xbcxecx9bx94xedx98xb8 xecx8bxa0xecxb2xadxedx95x98xeaxb5xac xeaxb3x84xecxa3x84xecx9dxb4xecxb2xb4xedx95x98xebxa0xa4xeaxb3xa0 xedx95x98xebx8ax94xebx8dxb0 xeaxb3x84xecxa2x8cxebxb2x88xedx98xb8xeaxb0x80 xecx9ex98xebxaaxbbxebx90xacxebx8bxa4xebx84xa4xecx9ax94 xe3x85xa0xe3x85xa0xe3x85xa0xecxa0x95xedx99x95xedx9ex88 xebxadx90xecxa3xa0', 'xebxb9x84 xecx98xa4xecxa7x80xeaxb2x8c xecx98xa4xebx8ax94xeaxb5xacxebx82x98', 'rt MENTION URL idiotapexecx9dx98 xeaxb3xb5xecx97xb0xebxaaxa8xecx8axb5xecx9ex85xebx8bx88xebx8bxa4', 'xebx82xb4xeaxb0x80 xebx82xb4xebxa6xb0 xecxbbxa4xedx94xbcxeaxb0x80 xecxb2x98xecx9dx8cxecx9cxbcxebxa1x9c xecx86x90xebx8bx98xedx95x9cxedx85x8cxe3x85x9cxebx82x98xeaxb0x94xebx8bxa4 xebxbfx8cxebx93xaf', 'MENTION actually u can be a fashionista with the baseball cap in korealol seriously most of the guys wear them lol', 'MENTION xecx9bx8cxecx9bx8cxecx9bx8c', 'xecx95x8axedx9ex98xebx93x9cxebx84xa4', 'MENTION xeaxbcxad xebx93xa4xebx9fxacxecxa3xbcxecx84xb8xecx9ax94', 'rt MENTION idiotape xeaxb3xb5xecx97xb0xecx98x81xecx83x81xecx9dxb4xebxb2x88 ggkxecx9dx98 xecxa7x84xecxa0x95xedx95x9c xedx97xa4xebx93x9cxebx9dxbcxecx9dxb4xebx84x88 xecx98x80xecx9dx8cxecxbaxacxecx98xa4 xecxbaxacxecx98xa4 URL', 'MENTION xecxa2x8bxecx9dx80 xecxa3xbcxebxa7x90 xebx90x98xecx8bx9cxeaxb8xb8 xe3x85x8bxe3x85x8bxe3x85x8b', 'xecx95x8cxebxb0x94xedx95x98xebx8ax94xebx8dxb0 xecx9dxb4xebxafxbcxecx9axb0 xecx99x94xebx8dxb4xebx8bxa4xecxa0xa0xecx9exa5 xecx9ex98xecx83x9dxeaxb2xbcxebx8dxb0xebxaaxbbxebxb4x90xecx84x9c xecx95x84xecx89xbd xecx97xb0xecx98x88xecx9dxb8xecx9dx80 xebx8cx93xeaxb9x94xecx9dxb4 xebx8bxa4xebxa5xb8xeaxb0x80xebxb4x90xecx97xac', 'xeaxb3xbcxecxa0x9cxecx96xb8xecxa0x9cxedx95xb4xeaxbax84 xeaxb7xb8xebx9ex98xedx94xbdxebx94x94xecx9ex90xecx9dxb8xecx9dxb4 xebx82xa0 xedx9ex98xebx93xa4xeaxb2x8cxedx95x98xebx8ax94xeaxb5xacxebx82x98 xe3x85x8bxe3x85x8b', 'MENTION xecx95xbc xebx84x88xebxadx90xecx95xbc xecx8bxa4xecx8bx9cxeaxb0x84 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx8axa4xebxa7x88xedx8axb8xedx8fxb0xebx8fx84 xecx95x84xebx8bx88xebxaax85xecx84x9c', 'MENTION xebxa7x8execx95x84xecx9ax94 xe3x85x8bxe3x85x8bxe3x85x8bxecxb0xb8xedx95x98xeaxb3xa0 xeaxb4x9cxecxb0xaexecx9dx80xecx82xacxebx9ex8c xecx99xb8xebxaaxa8 xecx95x8axebxb3xb4xebxa9xb4 ', 'MENTION xebx84xa4 xebxb0x98xeaxb0x80xecx9bx8cxecx9ax94 xe3x85x8exe3x85x8exe3x85x8e', 'xecxb2x9cxebx91xa5xecx9dx80 xebxacxb4xecx84x9cxecx9bx8c xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xe3x85x97xecx9cxbcxebx9ex91 xebx84x88xe3x85x93xecx96xb4xecx84xb8xecx83x81xecxa2x85xebxa7x90xecx98xacxebx93xafxedx95x9c xebx82xa0xecx94xa8', 'xecx98xa4xebx8ax98xecx9dx80 xecx8bxa0xebx82x98xebx8ax94 xeaxb8x88xecx9ax94xecx9dxbc', 'MENTION xecx9dx8cxecx9dxb4xeaxb1xb0 xedx96x89xecx82xacxeaxb0x80 xecx96xb8xecxa0x9cxecx9dxb8xeaxb0x80xecx9ax94', 'MENTION', 'MENTION xedx95x99xeaxb5x90xeaxb0x94xebx83x90 xe3x85x89xe3x85x89', 'MENTION xebxadx90 xecx97x86xecx96xb4xecx9ax94 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx97xb0xebx9dxbdxecx9dxb4 xecx97x86xeaxb1xb0xebx93xa0xecx9ax94 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx97x90xecx9ex87', 'MENTION xebx82xb4xecx9dxbc xecx9axb0xebxa6xac xecxa1xb8xecxa0x84 xeaxb0x80xecx95xbcxecxa7x80xe3x85x8exe3x85x8exe3x85x8e xeaxb8xb0xebx8cx80xebx90x9cxebx8bxa4 xecx95x84xeaxb9x8c xecx9dxb4xedx95x99xebx85x84xebx93xa4 xecx98xa4xebx9dxbcxeaxb3xa0 xedx95x98xebx8dx98xebx8cx80 xebxadx94xecx9dxbc', 'MENTION xecx9dxbcxecx96xb4xebx82x98xebxa9xb4 xecx97xb0xebx9dxbdxedx95x98xecx84xb8xecx97xac', 'MENTION xe3x85x8bxe3x85x8bxedx95x9cxebxb2x88 xebxb4x90xecx84x9cxebx8ax94xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx9axb0xecx84xa0 xebx8dx94xecx9axb4 xebx82xa0xecx94xa8xecx97x90xebx8fx84 xecx9axb4xebx8fx99xedx99x94xecx8bxa0xecx97x88xebx8bxa4xebx8ax94 xeaxb1xb0xecx97x90 xedx81xb0 xedx94x8cxebx9fxacxecx8axa4', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxedx97xa4xecx9dxb4 xebx89xb4xecx9ax94xecxbbxa4', 'rt MENTION URL  my sis i made some green tea cupcakes EMOJIBlackHeartSuit  xeaxb3xbcxecx99xb8xeaxb0x80xeaxb8xb0xecxa0x84xecx97x90zz', 'MENTION xecx9ax94xecxa6x98 xedx95x98xebx8ax98xecx9dxb4 xebx84x88xebxacxb4 xecx9dxb4xecx81x9cxeaxb1xb0 xeaxb0x99xecx95x84xecx9ax94 xebx8dx94xecx9bx8cxebx8fx84 xedx95x98xebx8ax98xebx95x9cxecx97x90 xebxb0x96xecx97x90 xecx9ex88xebx8ax94xebx8bxa4xebx8ax94 xebxb0xa4xedx95x98xebx8ax98xebx8fx84 xeaxbcxad xebxb3xb4xecx8bx9cxeaxb8xb8', 'xedx94x8cxebx9dxbcxecx9ex90 xedx98xb8xedx85x94 xebxa9x8bxecx9ex88xebx8bxa4 URL', 'xecx95x8cxebxb0x94xecxa4x91xecx9exacxebxb0x8cxeaxb2x8c xecx95x84xecx9ex90xecx95x84xecx9ex90', 'xecx84x9cxecx9exa5xebx8bx98xecx9dxb4 xebxa7x8cxebx93xa4xebx84x88xecxa3xbcxeaxb8xb4 xecx82xacxecx9dxb4xeaxb3xb5 xecxbbxa4xedx94xbc xe3x85x8bxe3x85x8bxebxbfx85xeaxb0x94xecx9dx8c  URL', 'MENTION xeaxb7xbcxecx84xb1xeaxb3xbc xebx81x88xeaxb8xb0xebxa5xbc xebxb3xb4xeaxb2xa0xecx96xb4xecx9ax94 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx98xa4xebxb9xa0 xebxacxb4xecx84x9cxecx9bx8cxecx9ax94xe3x85x8bxe3x85x8bxe3x85x8bxecxb6x94xeaxb2xa9xecx9ex90xecx95xbc xecx99x84xecxa0x84 xeaxb8xb0xebx8bxacxebxa6xacxebx8ax94 xecx9ex90xecx97x90xeaxb2x8c xebxb3xb5xecx9dxb4 xecx9ex88xebx82x98xebx8bx88', 'MENTION xebx82xb4xecx9dxbc xecx98xa4xedx94x84xebx8bx9dxecx9dxb4xebx9dxbcxecx84x9c xebx8bxa4 xecxb0xb8xeaxb0x80xedx95xb4xecx95xbcxebx90x98xebx8ax94xeaxb1xb0 xecx95x84xebx8bx98xe3x85x8exe3x85x8exe3x85x8execx96xb4xecxb0xa8xedx94xbc xebxadx90 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION xe3x85x8exe3x85x8exe3x85x8exeaxb7xb8xebx9ex98xecx95xbcxedx95x98xebx82x98xebxb4x90xecx9ax94 xe3x85x8exe3x85x8exeaxb8xb8xeaxb1xb0xebxa6xacxecx97x90xecx84x9c xebx83x85xebx8bxa4 xedx8cx94xeaxb8xb0xecx97x94 xecx9cx84xedx97x98xedx95x98xebx8bx88xeaxb9x90 xe3x85xa0xe3x85xa0', 'MENTION xecx98xa4 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxebx82xa0 xebx84x98 xecxa2x8bxecx95x84xedx95x98xecxa7x84xebxa7x88', 'MENTION xecx9ex84xebxa7x88 xecxa2x80 xebxb0xb0xecx9bx8c', 'MENTION xebxb0x94xebxa1x9c xecx98xacxebxa6xacxebx8ax94xecx84xbcxecx8axa4', 'xebx8bxa4xecx8bx9c xedx95x99xeaxb5x90xecx97x90 xecxa0x81xecx9dx91xedx95xb4xecx95xbcxebx90x98xebx8ax94xeaxb2x8c xecx8bxabxebx8bxa4 xecx99x95xecx96xb4xecx83x89', 'typographyxecx97x90 xecx9exacxebxafxb8xebxa5xbc xebxb6x99xecx97xacxebxb3xb4xecx9ex90', 'MENTION xecx95x84xeaxb9x8c xecx82xbcxeaxb0x81xecxa7x80xecx97x90xecx84x9c xecxbbxa4xedx94xbc xecx82xacxebx93x9cxecx85xa8xecxa3xa0xecx8axa4xedx86xa0xecxbbxa4 xecxa0x88xebx8cx80 xecx95x84xebx8bx98 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION xebxaaxb0xebx9ex90xebx84xa4xecx9ax94xe3x85xa0xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxebx84x88xebxacxb4xecxa1xb0xecx9axa9xedx9ex88 xeaxb3x84xecx85x94xecx84x9c xe3x85x8exe3x85x8e xe3x85x8bxe3x85x8bxe3x85x81xecxa2x80xebx8dx94 xebxb9xa8xebxa6xac xecx95x8cxecx95x84xebxb5x9cxecx96xb4xecx95xbcxedx96x88xebx8ax90xebx8dxb0 xe3x85xa0', 'xecx98xa4xebx8ax98xecx9dx80 xecx98xa8xebx8fx8cxecxa7x80xedx82xb4xecx9dxb4 xebx82xb4xeaxb0x80 xecxa1xb0xecx95x84xebx9dxbcxedx95x98xebx88x88xecx83x89xeaxb0x90xebx93xa4 URL', 'life is just a cup of cake xecx97x90xeaxb0x94xebx8bxa4 xecxa7x80xecxb9x98xeaxb3xa0 xedx9ex98xebx93xa4xebx95x8cxebxa9xb4 xebx8bxa8xeaxb2x8cxecxb5x9cxeaxb3xa0 URL', 'MENTION i enjoyed reading ur article lol i laughed like a retard during class while reading basball cap lol always luv ur writing ', 'MENTION xecx98xa4xecx9axb0 xeaxb7xb8xeaxb1xb0 xecx95x84xecxa7x81xebx8fx84 xedx95x98xebx8ax94xeaxb5xacxebx82x98 xeaxb7xb8xebx9ex98xebxaaxb0xecx95x84xebxb6x99xecx9dxbcxebx95x8c xebxb3xb4xeaxb3xa0xecx8bxb6xecx9dx80xebxb2x95 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION xecx9exbc', 'MENTION xecx9dxb4xebxb2xa4xedx8axb8 xecxb0xb8xecx97xac xecx8bxa0xecxb2xadxecx9dx80 xecx96xb8xecxa0x9cxebxb6x80xedx84xb0xecx9dxb8xeaxb0x80xecx9ax94xe3x85x8e', 'xebxa7x8cxecx9bx90xebxb9xb5 xebx82xb4xeaxb8xb0xecx97x90xecx84x9c xecx9dxb4xeaxb2xbcxebx8bxa4xe3x85x8bxe3x85x8bxecx98xa4xebxa7x8cxecx9bx90xedx95xa0xeaxbbx84', 'MENTION xecxbbxa4xedx94xbcxecxa7x91xecx95x8cxebxb0x94 xedx95xb4xecx9ax94', 'MENTION xe3x85x8exe3x85x8execx99xa0xecxa7x80 xecx88x98xebxafxbcxecx96xb8xebx8bx88xecxaaxbdxecx9dxb4 xebx8dx94 xecx84xa4xebx93xa4xebxa0xa5xecx9ex87xebx84xa4xecx9ax94 xe3x85x8exe3x85x8execx96xb4xecxa9x94xecx88x98 xebx84x9axebx8ax94 xecx84xb8xecx83x81xecx97x90xecx9dxb4xecxb9x98xecx9ex84xeaxb0x80xebxb4x90xecx9ax94', 'MENTION xedx95x98xeaxb3xa0 xecx96xb4xecxa0x9cxebx83x88xebx88x88xebx8dxb0 xeaxb3xa0xecxb3x90xecx95xbcxebx90x98xeaxb7x80xecxb0xae', 'MENTION xecx96xb4xecxa0x9c tcp xeaxb3xb5xecx97xb0 xecxb5x9cxeaxb3xa0 xecx98x80xecx8axb5xebx8bx88xebx8bxa4xecx95x84 xeaxb4x80xecxa0x88xecx9dxb4 xecx95x84xedx94x84xebx84xa4xecx97xac xe3x85x8e', 'nsxecx9cxa4xecxa7x80xebx9dxbcxebx8ax94 xecx97xb0xecx98x88xecx9dxb8xecx9dxb4 xecx9axb0xebxa6xac xecxbbxa4xedx94xbcxecx83xbexecx97x90 xebx93xa4xecx96xb4xecx98xb4xecx95x84 xeaxb7xb8xebxa0x87xeaxb5xacxebx82x98xecx96xbcxeaxb5xb4xecx9dx80 xecx9ex91xebx84xa4', 'MENTION xedx98xbcxecx9ex90xecx95x84xecxa3xbc xebx89xb4xecx9ax94xecxbbxa4 xecx95x84xecxb9xa8xecx9dxb4xeaxb5xacxebxa7x8c', 'xebx82x9c xecxa2x80 xebxb3x91xecx8bxa0xecx9dxb8xeaxb0x80xebxb3xb4xebx8bxa4', 'MENTION xecx84xb1xebxb6x81xebx8fx99xecx97x90xecx84x9c xecx9bx94xecx88x98xeaxb8x88 xedx8cx90xebxa7xa4xecx95x8cxebxb0x94 xeaxb5xacxedx95xa9xebx8bx88xebx8bxa4xecx8bx9cxeaxb8x89 xecx9cxa1xecxb2x9cxecx9bx90 xedx95x9cxebx8bxacxebxa7x8c xebx8fx84xecx99x80xecxa3xbcxebxa9xb4xebx90x9cxebx8bxa4xeaxb3xa0 xedx95xb4xecx9ax94 01050415723xebx84x90xebxa6xacxedx8dxbcxedx8axb8xebxa0xa4xecxa3xbcxecx8bx9cxecx84xb8xecx9ax94', 'xecx8bxacxecx8bxacxedx95x98xebx8bxa4 xebxa7x90 xeaxb1xb8xecx96xb4xecxa3xbcxecx84xb8xecx9ax94 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'xecxbbxa4xecx96xb4xedx94xbcxedx9ex88xecx9dxb4', 'xecx95x84xecx95x8cxebxb0x94xecx97xacxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxebx82xb4 xebxb0x9cxecx9dx84 xebxb6x99xecx9exa1xebx8ax94xeaxb5xacxebx82xad', 'MENTION xecx95x84xecxa7x81 xebxb3xb8xeaxb1xb4 xedx95x9cxebxb2x88xecx9dxb8xebx8dxb0 xeaxbdxa4 xecx9ex88xebx82x98xebxb4x90xecx9ax94 xe3x85x8exe3x85x8exe3x85x8exe3x85x8e', 'MENTION xebxadx94xecx95x8cxebxb0x94xecx82xacxecx97x85xecx9dxb4xeaxb1xb0xeaxb0x80xebx8ax94 xeaxb7xb8xebx9fxb0 xecx95x8cxebxb0x94xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION xebx84xa4 xeaxb7xb8xebx9ex98xecx84x9c xecx98xa4xebx8ax98 xebx8fx88 xecxa2x80 xecx93xb0xebx84xa4xecx9ax94 xe3x85x8exe3x85x8exe3x85x8exe3x85x8e', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxecx9cxa0xebxa3x8cxecx97x90xecx97xbc', 'MENTION xebx98x90 xecx95x8axecx98xa4xecx84xb8xecx9ax94xe3x85xa0 xe3x85x8bxe3x85x8bp', 'xeaxb3xbcxecxa0x9cxebxa5xbc xedx95xb4 xebxa7x90xecx96xb4', 'MENTION xebx8bxa4 xecxa2x8bxecx95x84 xe3x85x8bxe3x85x8bxe3x85x8bxecx82xb0xebx8bxa4xebx9dxbc xecxa9x94xecx96xb4', 'MENTION xecx95x84 xecx99xa4xecxbax90 xecx9bx83xeaxb8xb0xecxa3xa0xecx9bx83xecx9cxbcxebxa9xb4 xecx95x88xebx90x98xebx8ax94xebx8dxb0 xe3x85xa0xe3x85xa0xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION xeaxb4x9cxecxb0xaexecx8axb5xebx8bx88xebx8bxa4xecx95x84 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx86x8cxeaxb0x9cxedx8cx85xecx9dxb4 xebx8bxa4 xeaxb7xb8xebxa0x87xecxa3xa0 xebxadx90 ', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxeaxb7xb8xecxa0x80 xecx8bxa4xebxa0xa5xecx9dx84 xedx82xa4xecx9axb0xeaxb3xa0 xecx8bxb6xebx84xa4xecx97xac xe3x85x8bxe3x85x8bxe3x85x8bxedx95x9c xecx8bx9cxeaxb0x84xebxa7x8cxedx81xbc xebxb0x9bxecxa7x80xebx8fx84 xebxaaxbbxedx95xa8 xe3x85x8bxe3x85x8b', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxedx8fxacxeaxb8xb0xedx95x98xecxa7x80 xecx95x8axecx95x84xecx9ax94 xe3x85x8bxe3x85x8bxeaxb7xbcxebx8dxb0 xebx84x88xebxacxb4 xeaxb8xb0xebx8cx80xebx8fx84 ', 'xebx86x80xeaxb3xa0 xecx8bxb6xeaxb2x8c xedx95xb4xebx8ax94 xecx95x8axebx96xa8xecx96xb4xecxa7x84xebx8bxa4', 'xecx95x84 xecx9exa0xeaxb3xbcxecx9dx98 xecx8bxb8xecx9bx80', 'xecx84x9cxecx9axb8xecx95xbcxeaxb2xbdxecx9dxb4 xebxa9x8bxecxa7x80xebx84xa4xecx97xac URL', 'xecx95x84xecxb9xa8xecx9dx80 xecx9dxb4xebx94x94xecx98xa4xedx85x8cxecx9ex8exeaxb3xbc xecx97x90xecx8axa4xedx94x84xebxa0x88xecx86x8cxebxa1x9c xecx8bx9cxecx9ex91', 'MENTION xecxa7x9cxecx8bx9d xecx82xacxecxa7x84xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx97xadxecx8bx9c xecx9ax94xecxa0x95xedx8fxacxecx8axa4', 'xebx82xadxecxb6xa9 xebx8bxa8xebxb9x84 xecx83x81xedx9axa8xebx8bx88xecx99x80 xebx85xb8xebx9fx89xecxa7x84xecx9cxbcxebxa1x9c xeaxb8x89 xedx9ax8cxebxa8xb9xecx9cxbcxebx9fxac xeaxb0x84xecxa0x81xecx9dxb4xecx9ex88xebx8bxa4 xecx99x95xecxb0xbdxebxa8xb9xeaxb3xa0 xeaxb7xb8xebx9exacxecxa7x80xecx9exacxebxafxb8xecx9ex88xecx97x88xebx8ax94xebx8dxb0 xe3x85x9cxe3x85x9c', 'MENTION xecx95x84 xecx99x84xecxa0x84 xecxa7x80xeaxb8x88 xecxa0x9c xecxa1xb4xecx8bxacxecx9dxb4xebx95x85xecx9cxbcxebxa1x9c xecxb6x94xebx9dxbdxecx8bxa4xecxa2x85 xeaxb8xb8xeaxb0x80xebx8bxa4 xebxb3xb4xebxa9xb4 xecxa3xbcxecx84x9cxecxa3xbcxecx84xb8xecx97xac', 'xecx9exacxebxafxb8xebx82x9c xecx9axb0xecx82xb0xebx93xa4 tail umbrella URL', 'MENTION xebxacxb4xecx8axa8 xecx9dxbcxeaxb8xb0xebxa5xbc xecx93xb0xecx85xa8xeaxb5xacxebxa7x8cxebxacxb8xecx9ex90xebxa5xbc xecx9dxb4xebxa0x87xeaxb2x8c xebxb3xb4xebx82xb4xebxb4x90xebx9ex94xe3x85x8bxe3x85x8b', 'xeaxb0x80xecx9dx84xecx9dxb8xebx8dxb0 xebx82x9c xecx95x8cxebxb0x94xecx99x80 xeaxb3xbcxecxa0x9c xecx83x9dxeaxb0x81xecx97x90xecxa7x80xecxb9x9cxebx8bxa4', 'MENTION xe3x85x8axe3x85x8b xecx97xbcxebxadx94 xecxb2xadxecx86x8cxecx97xac xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecxa7x84xecxa7x9c xe3x85x8bxe3x85x8bxecx88x98xeaxb3xa0xedx96x88xebx84xa4', 'MENTION xecx9exacxebxb0x8cxecx97x88xecx96xb4xecx9ax94 xe3x85x8exe3x85x8exe3x85x8e', 'MENTION xebx88x84xeaxb0x80 xeaxb7xb8xebx9ex98xecx9ax94xe3x85x8bxe3x85x8bxeaxb1x8d xebx8dxa4xecx9cxbcxecx98xa4 xecx9ex98xecx83x9dxeaxb2xbcxebx8bxa4 xecx9dxb4xeaxb0x80xecxa3xa0 xe3x85x8exe3x85x8exe3x85x8exe3x85x8e xecx98xa4xebxb9xa0 xecxa0x9cxeaxb0x80 xeaxb4x9cxecxb0xaexecx9dx80 xecx97xacxecx9ex90 xecx9ex88xecx9cxbcxebxa9xb4 xeaxbcxad xecx86x8cxeaxb0x9cxecx8bx9cxecxbcx9cxebx93x9cxebxa6xb4xeaxb9xa8xecx9ax94 xe3x85x8exe3x85x8exe3x85x8e', 'MENTION xecx97xadxecx8bx9c xeaxb8x80xebxa1x9cxebxb2x8c xebx82xadxecxb6xa9 xe3x85x8bxe3x85x8bxe3x85x8bxedx9ex9dxedx9ex9d xebxafxb8xebx94x94xecx96xb4xecx8axa4xedx84xb0xebx94x94 xeaxb0x99xecx9dxb4xedx95x98xebx82x98xecx8bxb6xecx97x88xebx88x88xebx8dxb0xe3x85x9cxecx97xadxecx8bx9c xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xe3x85xa0xebx8bxb4xeaxb8xb0xedx9ax8cxecx97x90', 'MENTION xecxa0x84 xecxa0x9cxecxb2x9c xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx96x8fxedx98xb8', 'MENTION xebxb8x94xebxa1x9cxeaxb7xb8xebxb3xb4xeaxb3xa0 xebx84x88xebxacxb4 xecxa2x8bxecx95x84xecx84x9c xedx8axb8xecx9cx84xedx84xb0 xebxa7x9bxedx8cx94 xecx8bxa0xecxb2xadxedx95xb4xecx97xac xe3x85x8exe3x85x8e', 'MENTION xebx84xa4xebx84xb9xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8b', 'xeaxb0x9cxeaxb0x95xebxa7x9execx9dxb4 xedx97xa4xebx82x98xebxa5xbcxedx96x88xebx8bxa4 URL', 'MENTION xecx9ax94xecxa6x98 xecxa0x84 xecxa4x91xebxa7xa4xecx9fx81xecx9dxb4 xecx97xadxedx95xa0 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8c', 'xecx8bxb8xecx9dxb4xebxa8xbc xebx94x94 xebx8bxaexecx95x98xebx8dxb0xe3x85x8bxe3x85x8bxebx82x9c xecx97xacxecx9ex94xebx8dxb0', 'MENTION xebx9cxa8xedx98x95xebxb3xb4xeaxb3xa0 xecx99x84xecxa0x84xedx8cxac xebx90x90xecx9cxbcxecx97xacxe3x85x8exe3x85x8exe3x85x8e', 'xebx88x88xebx91x90xebx8dxa9xecx9dxb4xecx97x90 xebxaaxa8xeaxb8xb0xebxacxbcxebxa0xb8xebx8bxa4 xe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION xecxa7x84xecxa7x9cxecx9ax94xecx99x80 xeaxb8x80xebxa1x9cxebxb2x8cxeaxb0x9cxebx8dx94xebxa7x81xecx97x90xeaxb0x80xebxa0xa4xeaxb3xa0xecx9ax94 xe3x85x8exe3x85x8execx96xb8xecxa0x9cxebx98x90 xeaxb3xb5xecx97xb0xedx95x98xecx8bx9cxebx8ax94xecxa7x80xecx9ax94', 'MENTION xeaxb7xb8xebxa0x87xeaxb5xacxebx82x98 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecxa0x84 xecx8bx9cxeaxb0x81xebx94x94xecx9ex90xecx9dxb8xeaxb3xbcxebx9dxbc xe3x85x8bxe3x85x8bxe3x85x8bxebxadx90 xecxa2x85xecx9dxb4xecxa1xb0xeaxb0x80xebxa6xacxebxa1x9c xedx95xa0xecx88x98xecx9ex88xebx8ax94xeaxb1xb4 xeaxb1xb0xecx9dx98 xebx8bxa4xedx95xb4xecx9ax94 xe3x85x8exe3x85x8e', 'xebxa8xb9xecx9dx84xebxb3xb5 xecx95x98xebx8ax94 xebx82xa0 xebxa8xb9xebx8ax94xeaxb2x8c xebx81x8axecx9dxb4xecxa7x88 xecx95x8axebx8ax94xeaxb5xacxebx82x98 xedx96x89xebxb3xb5xedx95x98xeaxb5xb0', 'MENTION xebx8bxb9xecx97xb0xedx95x98xecxa7x80 xeaxb0x80xecx95xbcxecxa7x80 xe3x85x8bxe3x85x8bxe3x85x8bxedx81xb0 xedx96x89xecx82xb0xebx8dxb0 xe3x85x8bxe3x85x8bxeaxb7xb8xebx94x94 xebxb9xa0xecx9dxb4xebxb9xa0xecx9dxb4xecxa7x80 xebxadx90', 'xecx84xb8xecx83x81xecx9dx80 xecx95x84xecxa7x81 xecx95x84xebxa6x84xebx8bxa4xecx9axb4 xeaxb3xb3xecx9dxb8xeaxb1xb0 xeaxb0x99xebx8bxa4 xecx9dxb4xecx97xbfxecxb0xa8', 'xecx98xa4xebx8ax98xecx9dx80 xecxa2x80 xedx9ex98xebx93xa4xeaxb5xb0xecx9ax94 xe3x85xa0xe3x85xa0', 'MENTION xecx82xbcxeaxb0x81xecxa7x80xebx9dxbcxeaxb3xa0 xebxa7x90xedx96x88xebx8ax94xebx8dxb0xecx9ax94', 'MENTION xecxa0x84 xecx95x84xecxa7x81 xedx95x99xecx83x9d xecxa0x95xebxa7x90 xecx8bxabxecx96xb4xecx98x81', 'espresso neededsos', 'xecx9bxa8xecx9dxb4xedx81xacxebxb3xb4 xecxa7x84xecxa7x9c xecx9exacxebxb0x8cxebx8bxa4', 'rt MENTION xecx9dxb4xebx9fxb0xecxa0x80xebx9fxb0 xecx9dxb4xecx9cxa0xebxa5xbc xebx8cx80xebxa9xb0 xecxa0x81xebx8bxb9xedx9ex88 xedx95x98xeaxb1xb0xebx82x98 xecx97xb0xecx8axb5xedx95x98xebx8ax94 xedx9bx84xebxb0xb0xebx93xa4xecx9dxb4 xecx9ex88xebx8bxa4 xecxa0x95xecx8bxa0xecxb0xa8xebxa0xa4xebx9dxbc xeaxb1xb0xeaxb8xb0xeaxb0x80 xecxa7x80xecx98xa5xebxb6x88xecx9dxbcxecxa7x80xecx96xb8xecxa0x95 xebxacxb4xebx8cx80xebx8bxa4 xecx95x84xebxacxb4xebxa6xac xecx97xb4xecx95x85xedx95x9c xedx99x98xeaxb2xbdxecx9dxb4xebx8dx94xebx9dxbcxebx8fx84 xebxb6x84xecx9cx84xeaxb8xb0xebxa5xbc xebxa7x8cxebx93xa4xecx96xb4xebx82xb4xebx8ax94 xeaxb2x83  xeaxb7xb8xeaxb2x83xecx9dxb4 xebx82xb4xeaxb0x80 xecx83x9dxeaxb0x81xedx95x98xebx8ax94 xebx94x94xecxa0x9cxecx9dxb4xeaxb0x80 xecxa7x80xebx85x80xecx95xbcxedx95xa0 xecxa0x9c 1xecx9dx98 xebx8dx95xebxaaxa9xecx9dxb4xebx8bxa4', 'MENTION xecxa0x80xedx9dxac xedx95x99xeaxb5x90xebx8fx84 xecx9ex88xeaxb5xac xecxa2x8bxebx84xa4xecx97xacxebxb0x98xeaxb0x91xecx8axb5xebx8bx88xebx8bxa4', 'rt MENTION MENTION xedx8cx94xebxa1x9cxecx9ex89 xeaxb0x90xecx82xacxedx95xa9xebx8bx88xebx8bxa4 xecx95x9execx9cxbcxebxa1x9cxebx8fx84 xecxb9x9cxeaxb5xacxebxb6x84xebx93xa4xeaxbbx98 xebxa7x8execx9dxb4 xecx86x8cxeaxb0x9cxedx95xb4xecxa3xbcxecx84xb8xecx9ax94', 'MENTION xecx98xa4xebxb9xa0 xecx9dxb4xebxb0x98xedx95x99xeaxb8xb0 xebx8bxa4xebx8bx88xecx84xb8xecx9ax94', 'MENTION xebx85xb9xedx99x94 xedx94x8cxebxa6xacxecxa6x88 xe3x85xa0 xecx95x88xebx90x98xebx82x98', 'xebxb3x91xecx8bxa0xeaxb0x80 xecx9dx80xeaxb2x83xebx93xa4', 'MENTION xecx95x84 xecx98x99 xecxb0xbexeaxb3xa0xecx9ex88xecx8axb5xebx8bx88xebx8bxa4xecx9ax94 xe3x85x8exe3x85x8execx95x84xecxa7x81 xeaxb8xb0xeaxb0x84 xebx82xa8xecx95x98xecx96xb4xecx9ax94 xe3x85x8exe3x85x8e', 'wheres my design history folderarghxecxa0xa0xecx9exa5 xedx99x94xebx82x98xebx8ax94xeaxb5xb0', 'xecx98xa4xebx8ax98xecx9dx80 xebx82xa0xecx94xa8xeaxb0x80 xebxa7x91xebx8bxa4', 'MENTION xedx9dxa0 xeaxb7xb8xebxa0x87xeaxb5xb0xecx9ax94xecx9dxb4xeaxb2x8c xecx9exa5xebx82x9cxecx9dxb4 xecx95x84xebx8bx88xebx84xa4xecx97xacxecx97xb4xecx8bxacxedx9ex88 xeaxbexb8xebxa0xa4xebx82x98xeaxb0x80xebx83x90xecxa0xb8 xe3x85x8exe3x85x8execx86x8cxebx82x98xeaxb8xb0 xecxa1xb0xecx8bxacxedx95x98xecx84xb8xecx95xbc', 'xecxa0x9cxebxb9xb5xecx99x95 xeaxb9x80xedx83x81xeaxb5xac xebxb0x95xecxa7x84xeaxb0x90 xebx84x98xecxb9x98xebx8ax94xeaxb5xb0 xe3x85x8bxe3x85x8bxe3x85x8b', 'MENTION xecx97xacxecxa0x84xedx9ex88 xedx95xa9xebx8bx88xebx8bxa4 xedx95x98xecxa7x80xebxa7x8c xecx98xa4xebx8ax98xebxa7x8cxedx81xbcxecx9dx80 xecxb5x9cxecx84xa0xecx9dx84 xebx8bxa4xedx95xb4xecx84x9c xebxa8xb9xeaxb3xa0xecx9ex87xecx96xb4xecx9ax94 xe3x85x8exe3x85x8exe3x85x8execxbax90xebx82x98xebx8bxa4 xecx96xb4xebx95x8cxecx9ax94', 'what is this', 'MENTION xedx95xb4xedx94xbcxecxb6x94xecx84x9d', 'MENTION the creators project xebx9dxbcxeaxb3xa0 xedx96x89xecx82xac xecxb0xb8xecx97xacxedx96x88xebx8ax94xebx8dxb0 xe3x85x8bxe3x85x8bxe3x85x8bxecxa7x84xecxa7x9c xecx9exacxebxafxb8xecx9ex88xecx97x88xecx9dx8cxecxa7xb1', 'MENTION xecx96xb8xebx8bx88 xebx82x98 xecx88x98xecxa7x80xebxa7x9bxedx8cx94xedx95xb4xecxa3xbcxecx85x8d', 'xebx8axa6xecx9dx80xecx8bx9cxeaxb0x84xecx97x90xebx8fx84 xecx9ex91xecx97x85xedx95x9cxebx8bxa4xedx99x94xecx9exa5xecx96xb8xecxa0x9c xecxa7x80xecx9axb0xecxa7x80', 'xecxb2x98xecx9dx8cxecx9cxbcxebxa1x9c xebx82xb4xeaxb0x80 xebxa7x8cxebx93xa0 xecxbbxa4xedx94xbcxeaxb0x80 xebxa7x9bxecx9ex88xecx97x88xebx8bxa4xebx8ax94 xecx86x90xebx8bx98xecx9dxb4 xecx9ex88xecx97x88xebx8bxa4 xecx9dxb4xebxa3xa8 xebxa7x90xedx95xa0xecx88x98 xecx97x86xecx9dxb4 xeaxb8xb0xecx81x98xebx8bxa4', 'vj xedx95x9cxebxb3x84xebx8fx84 xecx9dxb4xecxa0x9c xecx9cxa0xebxa6xac xeaxb0x80xeaxb2x8cxecx98xa8xebx8bxa4xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxedx95x98xecxa7x80xebxa7x8c xebxa7x90xebx8fx84 xebxaaxbbxebxb6x99xecx9dxb4xebx8ax94 xebx82x9c xecxb0x8cxecxa7x88', 'MENTION xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecx98xa4xecxbcx80xecx9dxb4 xecx95x8cxecx95x84xebxb3xbcxeaxb2x8cxecx9ax94 xe3x85x8e', 'xedx95x99xeaxb5x90xecx99x94xebx8ax94xebx8dxb0 xe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxe3x85x8bxecxa0x81xecx9dx91xecx95x8axebx90x9cxebx8bxa4

xc2xa3 = £
xc3xa1 = a
xd0xba = k
xd2xaf = y


https://github.com/carpedm20/emoji/blob/master/emoji/unicode_codes.py
"""

"""
test = "xedx95xa0xeaxbaxbc"
rgx = r"(x[a-f0-9]{2})"
test = re.sub(rgx, r'/\1', test)
test

b_test = test.encode('ascii')
"""
