# -*- coding: utf-8 -*-

import csv
#import gensim
import numpy as np
#from nltk.stem import WordNetLemmatizer, SnowballStemmer
from nltk.stem.porter import *
#from gensim import corpora, models
from sklearn.model_selection import cross_val_score, cross_val_predict
from sklearn.feature_extraction.text import TfidfVectorizer
from sklearn import svm, metrics
from scipy.sparse import coo_matrix, hstack
#import pandas as pd
import matplotlib.pyplot as plt
import re

"""
def loadDataset(filename):
    dataset = []
    with open('data/' + filename + '.csv') as csv_file:
        csv_reader = csv.reader(csv_file, delimiter=',')
        for row in csv_reader:
            dataset.append(row)
    return dataset
"""

def combineAllTweetsPerUser(dataset):
    users = {}
    for row in dataset:
        TWETINDEX = 5 if len(row) == 7 else 7
        username = row[1]
        if username in users:
            users[username][5] += row[TWETINDEX]
            #users[username][5].append(row[TWETINDEX])
        else:
            if len(row) == 7:
                users[username] = row[0:5] + [row[5], row[6]]
                #users[username] = row[0:5] + [[row[5]], row[6]]
            else:
                users[username] = [row[1], row[5], row[2], row[3], row[6], row[7], row[9]]
                #users[username] = [row[1], row[5], row[2], row[3], row[6], [row[7]], row[9]]
    return list(users.values())


def extractEmojis(users_tweets):
    emojis = []
    regex = r"EMOJI[a-zA-Z]+"
    for user in users_tweets:
        emojis.append(' '.join(re.findall(regex, user)))
    return emojis




#df = pd.read_csv('data/reduced.csv')
#users = df.groupby(['username', 'bio', 'display_name', 'class'])['text'].apply(' '.join).reset_index()
#data = loadDataset('total')
data = processedTweets
users = combineAllTweetsPerUser(data)
np.random.shuffle(users)

labels = {'unrelated': 0, 'pro_ed': 1, 'pro_recovery': 0, 'unrelater': 0}



users_train = users#[:int(len(users)*0.8)]
#users_test = users[int(len(users)*0.8):]


y_train = [labels[u[6]] for u in users_train]
#y_test = [labels[u[6]] for u in users_test]

#labels = df[6]
#corpus = df[5]




def getScores(x, y):
    clf = svm.LinearSVC()
    clf.fit(x, y)
    f1_score = cross_val_score(clf, x, y, cv=5, scoring='f1')
    f1_mean = np.mean(f1_score)
    print('f1', f1_mean)
    precision = cross_val_score(clf, x, y, cv=5, scoring='precision')
    p_mean = np.mean(precision)
    print('precision', p_mean)
    recall = cross_val_score(clf, x, y, cv=5, scoring='recall')
    r_mean = np.mean(recall)
    print('recall', r_mean)
    return p_mean, r_mean, f1_mean


latex_table = []

# Unigrams
tweet_corpus = [u[5] for u in users_train]
#tweet_corpus_test = [u[5] for u in users_test]
uni_vectorizer = TfidfVectorizer(ngram_range=(1, 1), stop_words='english', max_features=20000)
uni_x = uni_vectorizer.fit_transform(tweet_corpus)
#uni_x_test = uni_vectorizer.transform(tweet_corpus_test)
print('unigrams')
latex_table.append(['Unigrams'] + list(getScores(uni_x, y_train)))


# Bigrams
bi_vectorizer = TfidfVectorizer(ngram_range=(2, 2), stop_words='english', max_features=10000)
bi_x = bi_vectorizer.fit_transform(tweet_corpus)
#bi_x_test = bi_vectorizer.transform(tweet_corpus_test)
print('bigrams')
latex_table.append(['Bigrams'] + list(getScores(bi_x, y_train)))


# Username (user-id + displayname)
name_corpus = [u[0] + u[1] for u in users_train]
name_corpus_test = [u[0] + u[1] for u in users_test]
name_vectorizer = TfidfVectorizer(analyzer='char', ngram_range=(3, 15), stop_words='english', max_features=10000)
name_x = name_vectorizer.fit_transform(name_corpus)
#name_x_test = name_vectorizer.transform(name_corpus_test)
print('username')
latex_table.append(['Username'] + list(getScores(name_x, y_train)))


# Bio
bio_corpus = [u[3] for u in users_train]
bio_corpus_test = [u[3] for u in users_test]
bio_vectorizer = TfidfVectorizer(ngram_range=(1, 2), stop_words='english', max_features=2000)
bio_x = bio_vectorizer.fit_transform(bio_corpus)
#bio_x_test = bio_vectorizer.transform(bio_corpus_test)
print('bio')
latex_table.append(['Bio'] + list(getScores(bio_x, y_train)))


# Emojis
emoji_corpus = extractEmojis(tweet_corpus)
emoji_corpus_test = extractEmojis(tweet_corpus_test)
emoji_vectorizer = TfidfVectorizer(ngram_range=(1, 1), stop_words='english', max_features=20000)
emoji_x = emoji_vectorizer.fit_transform(emoji_corpus)
#emoji_x_test = emoji_vectorizer.transform(emoji_corpus_test)
print('emojis')
latex_table.append(['Emojis'] + list(getScores(emoji_x, y_train)))


# Combined scores
combined_x = hstack([uni_x, bi_x, name_x, bio_x, emoji_x])
#combined_x_test = hstack([uni_x_test, bi_x_test, name_x_test, bio_x_test, emoji_x_test])
print('combined')
latex_table.append(['Combined'] + list(getScores(combined_x, y_train)))



def create_table(matrix):
    table_string = ''
    for row in matrix:
        for element in row[:-1]:
            table_string += str(element) + ' & '
        table_string += str(row[-1]) + ' \\\\ \n'
    return table_string


print(create_table(latex_table))






# Confusion matrix combined
clf = svm.LinearSVC()
clf.fit(combined_x, y_train)
y_pred = clf.predict(combined_x_test)
conf_mat = metrics.confusion_matrix(y_test, y_pred)
print('confusion matrix')
print(conf_mat)



# Plots the most important words
def plot_coefficients(classifier, feature_names, top_features=20):
    coef = classifier.coef_.ravel()
    top_positive_coefficients = np.argsort(coef)[-top_features:]
    top_negative_coefficients = np.argsort(coef)[:top_features]
    top_coefficients = np.hstack([top_negative_coefficients, top_positive_coefficients])
    # create plot
    plt.figure(figsize=(15, 5))
    colors = ['red' if c < 0 else 'blue' for c in coef[top_coefficients]]
    plt.bar(np.arange(2 * top_features), coef[top_coefficients], color=colors)
    feature_names = np.array(feature_names)
    plt.xticks(np.arange(1, 1 + 2 * top_features), feature_names[top_coefficients], rotation=60, ha='right')
    plt.show()


#plot_coefficients(clf, feature_names)
