# -*- coding: utf-8 -*-
import csv
import codecs
import gensim
import nltk
import numpy as np
from nltk.stem import WordNetLemmatizer, SnowballStemmer
from nltk.stem.porter import *
from gensim import models
from sklearn import svm
from sklearn.model_selection import cross_val_score
import pyLDAvis
import pyLDAvis.gensim  # don't skip this
import matplotlib.pyplot as plt
#matplotlib inline

np.random.seed(0)

nltk.download('wordnet')

# NOTE: all functions take as input a tokenized text.
#stop_words = set(stopwords.words('english'))
#stop_words = gensim.parsing.preprocessing.STOPWORDS

def removeStopWords(tokens):
    filtered_sentence = [w for w in tokens if w not in gensim.parsing.preprocessing.STOPWORDS]
    return filtered_sentence


def lemmatize_stemming(tokens):
    stemmer = SnowballStemmer("english")
    newTokens = []
    for w in tokens:
        newTokens.append(stemmer.stem(WordNetLemmatizer().lemmatize(w, pos='v')))
    return newTokens


def preprocess(text):
    word_tokens = gensim.utils.simple_preprocess(text)
    text_stopwords_removed = removeStopWords(word_tokens)
    lemmatizedStemmed = lemmatize_stemming(text_stopwords_removed)
    return lemmatizedStemmed


# Follows this tutorial: https://towardsdatascience.com/topic-modeling-and-latent-dirichlet-allocation-in-python-9bf156893c24
# and https://www.machinelearningplus.com/nlp/topic-modeling-gensim-python/

def loadDataset(filename):
    dataset = []
    csv_reader = csv.reader(codecs.open('data/' + filename + '.csv', 'rU', 'utf-8'), delimiter=',')
    for row in csv_reader:
        dataset.append(row)
    return dataset



def combineAllTweetsPerUser(dataset):
    users = {}
    for row in dataset:
        TWETINDEX = 5 if len(row) == 7 else 7
        username = row[1]
        if username in users:
            users[username][5] += row[TWETINDEX]
        else:
            if len(row) == 7:
                users[username] = row[0:5] + [row[5], row[6]]
            else:
                print(row)
    return list(users.values())


data = loadDataset('train')
users = combineAllTweetsPerUser(data)

# if loading a sorted dataset
np.random.shuffle(users)


processed_docs = []
#for doc in exampleTweets:
#    processed_docs.append(preprocess(doc))
count = 0
for user in users:
    count += 1
    processed_docs.append(preprocess(user[5]))
    if count % 500 == 0:
        count


# Dictionary of the words in the texts
dictionary = gensim.corpora.Dictionary(processed_docs)

# Filters out words that appear in less than 15 documents and more than 50% of all documents
# Kan teste ut verdier for parameterene
dictionary.filter_extremes(no_below=20, no_above=0.5, keep_n=10000)

# Counts how many times the word is in the document
bow_corpus = [dictionary.doc2bow(doc) for doc in processed_docs]


train = bow_corpus#[:int(len(bow_corpus)*0.8)]
#test = bow_corpus[int(len(bow_corpus)*0.8):]

# TF-IDF
tfidf = models.TfidfModel(train)
corpus_tfidf = tfidf[train]


# LDA using BoW
lda_model = gensim.models.LdaMulticore(train, num_topics=20, id2word=dictionary, passes=2, workers=2)
#for idx, topic in lda_model.print_topics(-1):
#    print('Topic: {} \nWords: {}'.format(idx, topic))


# LDA using TF-IDF
lda_model_tfidf = gensim.models.LdaMulticore(corpus_tfidf, num_topics=20, id2word=dictionary, passes=2, workers=4)
#for idx, topic in lda_model_tfidf.print_topics(-1):
#    print('Topic: {} Word: {}'.format(idx, topic))


# Saving the model to a file that can be loaded at a later time
#temp_file = datapath("bow_model")
#lda_model.save(temp_file)

# a measure of how good the model is. lower the better.
#lda_model.log_perplexity(train)

# Compute Coherence Score another perfomrnace model, higher is better
#coherence_model_lda = models.CoherenceModel(model=lda_model, texts=processed_docs, dictionary=dictionary, coherence='c_v')
#coherence_lda = coherence_model_lda.get_coherence()
#print('\nCoherence Score: ', coherence_lda)

# Visualize the topics
#vis = pyLDAvis.gensim.prepare(lda_model, train, dictionary)
#pyLDAvis.save_html(vis, 'LDA_Visualization3.html')

# Running the LDA on one instance (just an example)
#for index, score in sorted(lda_model[bow_corpus[2]], key=lambda tup: -1*tup[1]):
#    print("\nScore: {}\t \nTopic: {}".format(score, lda_model.print_topic(index, 10)))

# creating a feature set from the data
labels = {'unrelated': 0, 'pro_ed': 1, 'pro_recovery': 0}



def createFeatureset(lda, corpus):
    featureset = []
    for i in range(len(bow_corpus)):
        label = labels[users[i][-1]]
        featureset.append(lda[corpus[i]] + [label])
    X = []
    y = []
    for i in range(len(featureset)):
        row = featureset[i]
        X.append([0]*15)
        for a, b in row[0:-1]:
            X[i][a] = b
        y.append(row[-1])
    X = np.array(X)
    y = np.array(y)
    return X, y


#clf = svm.SVC(gamma='scale', decision_function_shape='ovo')
#clf.fit(X, y)



def create_table(matrix):
    table_string = ''
    for row in matrix:
        for element in row[:-1]:
            table_string += str(element) + ' & '
        table_string += str(row[-1]) + ' \\\\ \n'
    return table_string


latex_table = []

def getScores(x, y):
    clf = svm.SVC(gamma='scale',)
    clf.fit(x, y)
    f1_score = cross_val_score(clf, x, y, cv=10, scoring='f1')
    f1_mean = np.mean(f1_score)
    print('f1', f1_mean)
    precision = cross_val_score(clf, x, y, cv=10, scoring='precision')
    p_mean = np.mean(precision)
    print('precision', p_mean)
    recall = cross_val_score(clf, x, y, cv=10, scoring='recall')
    r_mean = np.mean(recall)
    print('recall', r_mean)
    return p_mean, r_mean, f1_mean


x, y = createFeatureset(lda_model, train)
latex_table.append(getScores(x, y))
x, y = createFeatureset(lda_model_tfidf, corpus_tfidf)
latex_table.append(getScores(x, y))


print(create_table(latex_table))



for n in [10, 20, 30, 50]:
    print(n)
    dictionary = gensim.corpora.Dictionary(processed_docs)
    dictionary.filter_extremes(no_below=20, no_above=0.5, keep_n=10000)
    bow_corpus = [dictionary.doc2bow(doc) for doc in processed_docs]
    train = bow_corpus#[:int(len(bow_corpus)*0.8)]
    tfidf = models.TfidfModel(train)
    corpus_tfidf = tfidf[train]
    lda_model = gensim.models.LdaMulticore(train, num_topics=15, id2word=dictionary, passes=2, workers=2)
    lda_model_tfidf = gensim.models.LdaMulticore(corpus_tfidf, num_topics=15, id2word=dictionary, passes=2, workers=4)
    x, y = createFeatureset(lda_model, train)
    latex_table.append(["BoW", n, 15] + list(getScores(x, y)))
    x, y = createFeatureset(lda_model_tfidf, corpus_tfidf)
    latex_table.append(["TF-IDF", n, 15] + list(getScores(x, y)))


print(create_table(latex_table))


# Determining the optimal number of topics.
"""
Compute c_v coherence for various number of topics
Parameters:
----------
dictionary : Gensim dictionary
corpus : Gensim corpus
texts : List of input texts
limit : Max num of topics

Returns:
-------
model_list : List of LDA topic models
coherence_values : Coherence values corresponding to the LDA model with respective number of topics
"""
def compute_coherence_values(dictionary, corpus, texts, limit, start=2, step=3):
    coherence_values = []
    model_list = []
    for num_topics in range(start, limit, step):
        print(num_topics)
        model = gensim.models.LdaMulticore(corpus, num_topics=num_topics, id2word=dictionary, passes=2, workers=2)
        model_list.append(model)
        print("Done making the model")
        coherencemodel = models.CoherenceModel(model=model, texts=texts, dictionary=dictionary, coherence='c_v')
        coherence_values.append(coherencemodel.get_coherence())
    return model_list, coherence_values


model_list, coherence_values = compute_coherence_values(dictionary=dictionary, corpus=train, texts=processed_docs, start=5, limit=25, step=3)

# Visualize the model
limit = 25
start = 5
step = 3
x = range(start, limit, step)
plt.plot(x, coherence_values)
plt.xlabel("Num Topics")
plt.ylabel("Coherence score")
plt.legend(("coherence_values"), loc='best')
plt.show()
