import CMUTweetTagger
import codecs
import csv
import numpy as np
from sklearn import svm
from sklearn.model_selection import cross_val_score
from sklearn.feature_extraction.text import TfidfVectorizer


def loadDataset(filename):
    dataset = []
    #with open('data/' + filename + '.csv') as csv_file:
    csv_reader = csv.reader(codecs.open('data/' + filename + '.csv', 'rU', 'utf-8'), delimiter=',')
    for row in csv_reader:
        dataset.append(row)
    return dataset


def combineAllTweetsPerUser(dataset):
    users = {}
    for row in dataset:
        if row[-1] == 'class': continue
        TWETINDEX = 5 if len(row) == 7 else 7
        username = row[1]
        if username in users:
            users[username][5] += row[TWETINDEX]
        else:
            if len(row) == 7:
                users[username] = row[0:5] + [row[5], row[6]]
            else:
                users[username] = [row[1], row[5], row[2], row[3], row[6], row[7], row[9]]
    return list(users.values())



data = loadDataset('train')
users = combineAllTweetsPerUser(data)
del data

labels = {'unrelated': 0, 'pro_ed': 1, 'pro_recovery': 0}
y = [labels[u[6]] for u in users]
tweet_corpus = [u[5] for u in users]


f = open("posTags.txt", "w")
f.close()

batch = []
for i in range(2730, len(tweet_corpus)):
    tags = ''
    user = tweet_corpus[i]
    posTags = (CMUTweetTagger.runtagger_parse([user]))
    for posTag in posTags[0]:
        tags += posTag[1]
    batch.append(tags)
    if i % 100 == 0:
        print(i)
        if len(batch) != 100:
            print("ERROR!!!")
        f = open("posTags.txt", "a")
        for tagString in batch:
            f.write(tagString + "\n")
        f.close()
        batch = []





"""
# Count the pos tags
unrelated = {}
proEd = {}
proRec = {}
for i in range(len(posTags)):
    for tweet in posTags[i]:
        for tag in tweet:
            if y[i] == 1:
                if tag[1] in proEd.keys():
                    proEd[tag[1]] += 1
                else:
                    proEd[tag[1]] = 1
            elif y[i] == 0:
                if tag[1] in unrelated.keys():
                    unrelated[tag[1]] += 1
                else:
                    unrelated[tag[1]] = 1
            else:
                if tag in proRec.keys():
                    proRec[tag[1]] += 1
                else:
                    proRec[tag[1]] = 1
"""


tagStrings = []
f = open("data/posTags.txt", "r")
for tagString in f.readlines():
    tagStrings.append(tagString)


f.close()


def getScores(x, y):
    clf = svm.LinearSVC()
    clf.fit(x, y)
    f1_score = cross_val_score(clf, x, y, cv=5, scoring='f1')
    f1_mean = np.mean(f1_score)
    print('f1', f1_mean)
    precision = cross_val_score(clf, x, y, cv=5, scoring='precision')
    p_mean = np.mean(precision)
    print('precision', p_mean)
    recall = cross_val_score(clf, x, y, cv=5, scoring='recall')
    r_mean = np.mean(recall)
    print('recall', r_mean)
    return p_mean, r_mean, f1_mean





uni_vectorizer = TfidfVectorizer(ngram_range=(3, 3), analyzer='char', max_features=20000)
# Use entire dataset for evaluating the performance
uni_x = uni_vectorizer.fit_transform(tagStrings)
#uni_x_test = uni_vectorizer.transform(test)
#print('unigrams')
getScores(uni_x, y)

def create_table(matrix):
    table_string = ''
    for row in matrix:
        for element in row[:-1]:
            table_string += str(element) + ' & '
        table_string += str(row[-1]) + ' \\\\ \n'
    return table_string




latex_table = []
for n in [6, 7]:
    latex_table.append([str(n)])
    uni_vectorizer = TfidfVectorizer(ngram_range=(n, n), analyzer='char', max_features=20000)
    uni_x = uni_vectorizer.fit_transform(tagStrings)
    latex_table.append(list(getScores(uni_x, y)))


print(create_table(latex_table))

