import csv
import codecs
import gensim
import numpy as np
from keras.preprocessing.text import Tokenizer
from keras.preprocessing.sequence import pad_sequences
from sklearn import svm
from sklearn.model_selection import cross_val_score


def loadDataset(filename):
    dataset = []
    #with open('data/' + filename + '.csv') as csv_file:
    csv_reader = csv.reader(codecs.open('data/' + filename + '.csv', 'rU', 'utf-8'), delimiter=',')
    for row in csv_reader:
        dataset.append(row)
    return dataset



def combineAllTweetsPerUser(dataset):
    users = {}
    for row in dataset:
        TWETINDEX = 5 if len(row) == 7 else 7
        username = row[1]
        if username in users:
            users[username][5] += row[TWETINDEX]
            #users[username][5].append(row[TWETINDEX])
        else:
            if len(row) == 7:
                users[username] = row[0:5] + [row[5], row[6]]
                #users[username] = row[0:5] + [[row[5]], row[6]]
            else:
                users[username] = [row[1], row[5], row[2], row[3], row[6], row[7], row[9]]
                #users[username] = [row[1], row[5], row[2], row[3], row[6], [row[7]], row[9]]
    return list(users.values())


def getScores(x, y):
    clf = svm.LinearSVC()
    clf.fit(x, y)
    f1_score = cross_val_score(clf, x, y, cv=5, scoring='f1')
    f1_mean = np.mean(f1_score)
    print('f1', f1_mean)
    precision = cross_val_score(clf, x, y, cv=5, scoring='precision')
    p_mean = np.mean(precision)
    print('precision', p_mean)
    recall = cross_val_score(clf, x, y, cv=5, scoring='recall')
    r_mean = np.mean(recall)
    print('recall', r_mean)
    return p_mean, r_mean, f1_mean


def document_avg_embedding(dataset):
    emb_avg = []
    # Averaging the word vectors for each text
    for vlog_index in range(len(dataset)):
        emb_total = np.zeros(GLOVE_DIM)
        for word_index in range(len(dataset[vlog_index])):
            # vil ikke ha dette vil ha embeddings ughhhhh
            emb_total = np.add(emb_total, emb_matrix[dataset[vlog_index, word_index]])
        emb_avg.append(emb_total / np.sqrt(emb_total.dot(emb_total)))
    return emb_avg


data = loadDataset('final')
users = combineAllTweetsPerUser(data)
np.random.shuffle(users)


labels = {'unrelated': 0, 'pro_ed': 1, 'pro_recovery': 0}


users_train = users[:int(len(users)*0.8)]
users_test = users[int(len(users)*0.8):]


y_train = [labels[u[6]] for u in users_train]
y_test = [labels[u[6]] for u in users_test]



NB_WORDS = 10000  # Parameter indicating the number of words we'll put in the dictionary
VAL_SIZE = int(len(users)*0.2)  # Size of the validation set
NB_START_EPOCHS = 10  # Number of epochs we usually start to train with
BATCH_SIZE = 512  # Size of the batches used in the mini-batch gradient descent
#MAX_LEN = 24  # Maximum number of words in a sequence


# This only removes stop words, leaving the text as a whole text
X_train = [gensim.parsing.preprocessing.remove_stopwords(user[5]) for user
           in users_train]
X_test = [gensim.parsing.preprocessing.remove_stopwords(user[5]) for user
          in users_test]
# Using keras tokenizer
tk = Tokenizer(num_words=NB_WORDS,
               filters='!"#$%&()*+,-./:;<=>?@[\]^_`{"}~\t\n',
               lower=True,
               split=" ")


# Fits the tokenizer on only the training data.
# This creates an index for each word in the training data
tk.fit_on_texts(X_train)
# Now X_train_seq will have a sequence of word indices representing the text
X_train_seq = tk.texts_to_sequences(X_train)
X_test_seq = tk.texts_to_sequences(X_test)

# This is a dictionary of all the words with their respective indices as values
# tk.word_index

# This makes all the sequences the same length (padding first)
# uses 0.0 as the padding since 0 is not in the indices for this reason
# fix the maxlen so that we pad all to be full length
X_train_seq_trunc = pad_sequences(X_train_seq, maxlen=677) #, maxlen=MAX_LEN (possible arg)
X_test_seq_trunc = pad_sequences(X_test_seq, maxlen=677)



GLOVE_DIM = 25  # Number of dimensions of the GloVe word embeddings (25, 50, 100 el 200)

# At this point we have a sequence of integers for each text,
# where each integer is the index of a word and the text could
# be reproduced by replacing the words for the indices.
glove_file = 'glove.twitter.27B.' + str(GLOVE_DIM) + 'd.txt'
# This is the dictionary that will hold the pretrained values from the model
emb_dict = {}
glove = open('personality/glove.twitter.27B/' + glove_file)
for line in glove:
    values = line.split()
    word = values[0]
    vector = np.asarray(values[1:], dtype='float32')
    emb_dict[word] = vector


glove.close()


# Start by initializing an empty matrix to ensure no missing values
emb_matrix = np.zeros((NB_WORDS, GLOVE_DIM))
# Loop through word : index pairs
# This essentially combines the trained glove values with the word indices
# replacing the word string as a key and using the index instead
for w, i in tk.word_index.items():
    # Since we are only keeping the first NB_WORDS words
    if i < NB_WORDS:
        # This was created by the GloVe model
        vect = emb_dict.get(w)
        if vect is not None:
            # Word i in the emb matrix now has the values of the pretrained model
            emb_matrix[i] = vect
    else:
        break


# We now have a matrix of words and embeddings and we need to find a representation
# of the whole text for each transcript.


# Average as a feature for the entire doc
emb_avg = document_avg_embedding(X_train_seq_trunc)
emb_avg_test = document_avg_embedding(X_test_seq_trunc)


getScores(emb_avg, y_train)

